/****************************************************************************
** Meta object code from reading C++ file 'PDFDocument.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../texstudio-4.9.3/src/pdfviewer/PDFDocument.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'PDFDocument.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12PDFMagnifierE_t {};
} // unnamed namespace

template <> constexpr inline auto PDFMagnifier::qt_create_metaobjectdata<qt_meta_tag_ZN12PDFMagnifierE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PDFMagnifier",
        "setImage",
        "",
        "QPixmap",
        "img",
        "pageNr"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'setImage'
        QtMocHelpers::SlotData<void(const QPixmap &, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Int, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PDFMagnifier, qt_meta_tag_ZN12PDFMagnifierE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PDFMagnifier::staticMetaObject = { {
    QMetaObject::SuperData::link<PDFDraggableTool::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12PDFMagnifierE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12PDFMagnifierE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12PDFMagnifierE_t>.metaTypes,
    nullptr
} };

void PDFMagnifier::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PDFMagnifier *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setImage((*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject *PDFMagnifier::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PDFMagnifier::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12PDFMagnifierE_t>.strings))
        return static_cast<void*>(this);
    return PDFDraggableTool::qt_metacast(_clname);
}

int PDFMagnifier::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PDFDraggableTool::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN15PDFLaserPointerE_t {};
} // unnamed namespace

template <> constexpr inline auto PDFLaserPointer::qt_create_metaobjectdata<qt_meta_tag_ZN15PDFLaserPointerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PDFLaserPointer"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PDFLaserPointer, qt_meta_tag_ZN15PDFLaserPointerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PDFLaserPointer::staticMetaObject = { {
    QMetaObject::SuperData::link<PDFDraggableTool::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15PDFLaserPointerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15PDFLaserPointerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15PDFLaserPointerE_t>.metaTypes,
    nullptr
} };

void PDFLaserPointer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PDFLaserPointer *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *PDFLaserPointer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PDFLaserPointer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15PDFLaserPointerE_t>.strings))
        return static_cast<void*>(this);
    return PDFDraggableTool::qt_metacast(_clname);
}

int PDFLaserPointer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PDFDraggableTool::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN9PDFWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto PDFWidget::qt_create_metaobjectdata<qt_meta_tag_ZN9PDFWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PDFWidget",
        "changedPage",
        "",
        "changedZoom",
        "changedScaleOption",
        "autoScaleOption",
        "syncClick",
        "QPointF",
        "activate",
        "goFirst",
        "goPrev",
        "goNext",
        "goLast",
        "goForward",
        "goBack",
        "doPageDialog",
        "magnifierClicked",
        "scrollClicked",
        "selectTextClicked",
        "fitWidth",
        "checked",
        "fitTextWidth",
        "zoomIn",
        "zoomOut",
        "jumpToSource",
        "upOrPrev",
        "leftOrPrev",
        "pageUpOrPrev",
        "downOrNext",
        "rightOrNext",
        "pageDownOrNext",
        "clearHighlight",
        "openAnnotationDialog",
        "const PDFAnnotation*",
        "annon",
        "setSinglePageStep",
        "step",
        "windowResized",
        "fitWindow",
        "setTool",
        "tool",
        "syncWindowClick",
        "QPoint",
        "p",
        "getPosFromClick",
        "syncCurrentPage",
        "fixedScale",
        "scale",
        "setImage",
        "QPixmap",
        "img",
        "pageNr",
        "delayedUpdate",
        "copyText",
        "normalizedPageIndex",
        "pageIndex",
        "goToPageDirect",
        "sync",
        "setHighlightPath",
        "QPainterPath",
        "path",
        "dontRemove",
        "getHighlightPage",
        "goToDestination",
        "destName",
        "goToPageRelativePosition",
        "page",
        "xinpage",
        "yinpage",
        "getPageIndex",
        "reloadPage",
        "visiblePages",
        "pseudoNumPages",
        "realNumPages",
        "pageStep",
        "gridCols",
        "fromConfig",
        "gridRows",
        "gridRowHeight",
        "gridBorder",
        "getPDFDocument",
        "PDFDocument*",
        "getPageOffset",
        "zoom"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changedPage'
        QtMocHelpers::SignalData<void(int, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Bool, 2 },
        }}),
        // Signal 'changedZoom'
        QtMocHelpers::SignalData<void(qreal)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'changedScaleOption'
        QtMocHelpers::SignalData<void(autoScaleOption)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'syncClick'
        QtMocHelpers::SignalData<void(int, const QPointF &, bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { 0x80000000 | 7, 2 }, { QMetaType::Bool, 8 },
        }}),
        // Slot 'goFirst'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'goPrev'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'goNext'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'goLast'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'goForward'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'goBack'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'doPageDialog'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'magnifierClicked'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'scrollClicked'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'selectTextClicked'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'fitWidth'
        QtMocHelpers::SlotData<void(bool)>(19, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'fitWidth'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessProtected | QMC::MethodCloned, QMetaType::Void),
        // Slot 'fitTextWidth'
        QtMocHelpers::SlotData<void(bool)>(21, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'fitTextWidth'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessProtected | QMC::MethodCloned, QMetaType::Void),
        // Slot 'zoomIn'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'zoomOut'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'jumpToSource'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'upOrPrev'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'leftOrPrev'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'pageUpOrPrev'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'downOrNext'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'rightOrNext'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'pageDownOrNext'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'clearHighlight'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'openAnnotationDialog'
        QtMocHelpers::SlotData<void(const PDFAnnotation *)>(32, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Slot 'setSinglePageStep'
        QtMocHelpers::SlotData<void(bool)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 36 },
        }}),
        // Slot 'windowResized'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'fitWindow'
        QtMocHelpers::SlotData<void(bool)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'fitWindow'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setTool'
        QtMocHelpers::SlotData<void(int)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 40 },
        }}),
        // Slot 'syncWindowClick'
        QtMocHelpers::SlotData<void(const QPoint &, bool)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 42, 43 }, { QMetaType::Bool, 8 },
        }}),
        // Slot 'getPosFromClick'
        QtMocHelpers::SlotData<void(const QPoint &)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 42, 43 },
        }}),
        // Slot 'syncCurrentPage'
        QtMocHelpers::SlotData<void(bool)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'fixedScale'
        QtMocHelpers::SlotData<void(qreal)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 47 },
        }}),
        // Slot 'fixedScale'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setImage'
        QtMocHelpers::SlotData<void(QPixmap, int)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 49, 50 }, { QMetaType::Int, 51 },
        }}),
        // Slot 'delayedUpdate'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copyText'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'normalizedPageIndex'
        QtMocHelpers::MethodData<int(int)>(54, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 55 },
        }}),
        // Method 'goToPageDirect'
        QtMocHelpers::MethodData<void(int, bool)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 55 }, { QMetaType::Bool, 57 },
        }}),
        // Method 'setHighlightPath'
        QtMocHelpers::MethodData<void(const int, const QPainterPath &, const bool)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 55 }, { 0x80000000 | 59, 60 }, { QMetaType::Bool, 61 },
        }}),
        // Method 'setHighlightPath'
        QtMocHelpers::MethodData<void(const int, const QPainterPath &)>(58, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 55 }, { 0x80000000 | 59, 60 },
        }}),
        // Method 'getHighlightPage'
        QtMocHelpers::MethodData<int() const>(62, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'goToDestination'
        QtMocHelpers::MethodData<void(const QString &)>(63, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 64 },
        }}),
        // Method 'goToPageRelativePosition'
        QtMocHelpers::MethodData<void(int, double, double)>(65, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 66 }, { QMetaType::Double, 67 }, { QMetaType::Double, 68 },
        }}),
        // Method 'getPageIndex'
        QtMocHelpers::MethodData<int()>(69, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'reloadPage'
        QtMocHelpers::MethodData<void(bool)>(70, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 57 },
        }}),
        // Method 'reloadPage'
        QtMocHelpers::MethodData<void()>(70, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'visiblePages'
        QtMocHelpers::MethodData<int() const>(71, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'pseudoNumPages'
        QtMocHelpers::MethodData<int() const>(72, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'realNumPages'
        QtMocHelpers::MethodData<int() const>(73, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'pageStep'
        QtMocHelpers::MethodData<int()>(74, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'gridCols'
        QtMocHelpers::MethodData<int(bool) const>(75, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Bool, 76 },
        }}),
        // Method 'gridCols'
        QtMocHelpers::MethodData<int() const>(75, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int),
        // Method 'gridRows'
        QtMocHelpers::MethodData<int(bool) const>(77, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Bool, 76 },
        }}),
        // Method 'gridRows'
        QtMocHelpers::MethodData<int() const>(77, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int),
        // Method 'gridRowHeight'
        QtMocHelpers::MethodData<int() const>(78, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'gridBorder'
        QtMocHelpers::MethodData<int() const>(79, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'getPDFDocument'
        QtMocHelpers::MethodData<PDFDocument *()>(80, 2, QMC::AccessPublic, 0x80000000 | 81),
        // Method 'getPageOffset'
        QtMocHelpers::MethodData<int() const>(82, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'zoom'
        QtMocHelpers::MethodData<void(qreal)>(83, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 47 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PDFWidget, qt_meta_tag_ZN9PDFWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PDFWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QLabel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9PDFWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9PDFWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9PDFWidgetE_t>.metaTypes,
    nullptr
} };

void PDFWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PDFWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changedPage((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 1: _t->changedZoom((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 2: _t->changedScaleOption((*reinterpret_cast<std::add_pointer_t<autoScaleOption>>(_a[1]))); break;
        case 3: _t->syncClick((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 4: _t->goFirst(); break;
        case 5: _t->goPrev(); break;
        case 6: _t->goNext(); break;
        case 7: _t->goLast(); break;
        case 8: _t->goForward(); break;
        case 9: _t->goBack(); break;
        case 10: _t->doPageDialog(); break;
        case 11: _t->magnifierClicked(); break;
        case 12: _t->scrollClicked(); break;
        case 13: _t->selectTextClicked(); break;
        case 14: _t->fitWidth((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->fitWidth(); break;
        case 16: _t->fitTextWidth((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->fitTextWidth(); break;
        case 18: _t->zoomIn(); break;
        case 19: _t->zoomOut(); break;
        case 20: _t->jumpToSource(); break;
        case 21: _t->upOrPrev(); break;
        case 22: _t->leftOrPrev(); break;
        case 23: _t->pageUpOrPrev(); break;
        case 24: _t->downOrNext(); break;
        case 25: _t->rightOrNext(); break;
        case 26: _t->pageDownOrNext(); break;
        case 27: _t->clearHighlight(); break;
        case 28: _t->openAnnotationDialog((*reinterpret_cast<std::add_pointer_t<const PDFAnnotation*>>(_a[1]))); break;
        case 29: _t->setSinglePageStep((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 30: _t->windowResized(); break;
        case 31: _t->fitWindow((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 32: _t->fitWindow(); break;
        case 33: _t->setTool((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 34: _t->syncWindowClick((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 35: _t->getPosFromClick((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 36: _t->syncCurrentPage((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 37: _t->fixedScale((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 38: _t->fixedScale(); break;
        case 39: _t->setImage((*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 40: _t->delayedUpdate(); break;
        case 41: _t->copyText(); break;
        case 42: { int _r = _t->normalizedPageIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 43: _t->goToPageDirect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 44: _t->setHighlightPath((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPainterPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 45: _t->setHighlightPath((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPainterPath>>(_a[2]))); break;
        case 46: { int _r = _t->getHighlightPage();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 47: _t->goToDestination((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 48: _t->goToPageRelativePosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3]))); break;
        case 49: { int _r = _t->getPageIndex();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 50: _t->reloadPage((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 51: _t->reloadPage(); break;
        case 52: { int _r = _t->visiblePages();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 53: { int _r = _t->pseudoNumPages();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 54: { int _r = _t->realNumPages();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 55: { int _r = _t->pageStep();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 56: { int _r = _t->gridCols((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 57: { int _r = _t->gridCols();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 58: { int _r = _t->gridRows((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 59: { int _r = _t->gridRows();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 60: { int _r = _t->gridRowHeight();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 61: { int _r = _t->gridBorder();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 62: { PDFDocument* _r = _t->getPDFDocument();
            if (_a[0]) *reinterpret_cast<PDFDocument**>(_a[0]) = std::move(_r); }  break;
        case 63: { int _r = _t->getPageOffset();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 64: _t->zoom((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PDFWidget::*)(int , bool )>(_a, &PDFWidget::changedPage, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PDFWidget::*)(qreal )>(_a, &PDFWidget::changedZoom, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PDFWidget::*)(autoScaleOption )>(_a, &PDFWidget::changedScaleOption, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PDFWidget::*)(int , const QPointF & , bool )>(_a, &PDFWidget::syncClick, 3))
            return;
    }
}

const QMetaObject *PDFWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PDFWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9PDFWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QLabel::qt_metacast(_clname);
}

int PDFWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QLabel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 65)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 65;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 65)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 65;
    }
    return _id;
}

// SIGNAL 0
void PDFWidget::changedPage(int _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void PDFWidget::changedZoom(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PDFWidget::changedScaleOption(autoScaleOption _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void PDFWidget::syncClick(int _t1, const QPointF & _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}
namespace {
struct qt_meta_tag_ZN11PDFDocumentE_t {};
} // unnamed namespace

template <> constexpr inline auto PDFDocument::qt_create_metaobjectdata<qt_meta_tag_ZN11PDFDocumentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PDFDocument",
        "documentClosed",
        "",
        "documentLoaded",
        "syncSource",
        "sourceFile",
        "line",
        "activate",
        "guessedWord",
        "syncView",
        "pdfFile",
        "QFileInfo",
        "masterFile",
        "page",
        "focusEditor",
        "fileDropped",
        "QUrl",
        "url",
        "runCommand",
        "command",
        "currentFile",
        "linenr",
        "triggeredAbout",
        "triggeredManual",
        "triggeredQuit",
        "triggeredPlaceOnLeft",
        "triggeredConfigure",
        "triggeredEnlarge",
        "triggeredShrink",
        "triggeredClone",
        "reloadSettings",
        "loadCurrentFile",
        "fillCache",
        "fillRenderCache",
        "pg",
        "sideBySide",
        "doFindDialog",
        "doFindAgain",
        "goToSource",
        "toggleFullScreen",
        "fullscreen",
        "syncFromSource",
        "lineNo",
        "column",
        "PDFDocument::DisplayFlags",
        "displayFlags",
        "syncFromView",
        "loadFile",
        "fileName",
        "printPDF",
        "setAutoHideToolbars",
        "enabled",
        "hideToolbars",
        "showToolbars",
        "showToolbarsDelayed",
        "setToolbarIconSize",
        "sz",
        "showMessage",
        "text",
        "splitMergeTool",
        "fileOpen",
        "enablePageActions",
        "enableZoomActions",
        "adjustScaleActions",
        "autoScaleOption",
        "syncClick",
        "QPointF",
        "pos",
        "stopReloadTimer",
        "reloadWhenIdle",
        "idleReload",
        "runExternalViewer",
        "runInternalViewer",
        "toggleEmbedded",
        "toggleAutoHideToolbars",
        "runQuickBuild",
        "setGrid",
        "closeElement",
        "tileWindows",
        "stackWindows",
        "unminimize",
        "updateDisplayState",
        "arrangeWindows",
        "tile",
        "updateToolBarForOrientation",
        "Qt::Orientation",
        "orientation",
        "jumpToPage",
        "search",
        "backward",
        "incremental",
        "clearHightlight",
        "visible",
        "gotoAnnotation",
        "const PDFAnnotation*",
        "ann",
        "zoomFromAction",
        "zoomSliderChange",
        "enlarge",
        "shrink",
        "getMasterFile",
        "zoomToRight",
        "QWidget*",
        "otherWindow",
        "showPage",
        "setResolution",
        "res",
        "goToDestination",
        "destName",
        "goToPage",
        "focus",
        "widget",
        "PDFWidget*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'documentClosed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'documentLoaded'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'syncSource'
        QtMocHelpers::SignalData<void(const QString &, int, bool, const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::Int, 6 }, { QMetaType::Bool, 7 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'syncView'
        QtMocHelpers::SignalData<void(const QString &, const QFileInfo &, int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { 0x80000000 | 11, 12 }, { QMetaType::Int, 13 },
        }}),
        // Signal 'focusEditor'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fileDropped'
        QtMocHelpers::SignalData<void(const QUrl &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Signal 'runCommand'
        QtMocHelpers::SignalData<void(const QString &, const QFileInfo &, const QFileInfo &, int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 }, { 0x80000000 | 11, 12 }, { 0x80000000 | 11, 20 }, { QMetaType::Int, 21 },
        }}),
        // Signal 'triggeredAbout'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'triggeredManual'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'triggeredQuit'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'triggeredPlaceOnLeft'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'triggeredConfigure'
        QtMocHelpers::SignalData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'triggeredEnlarge'
        QtMocHelpers::SignalData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'triggeredShrink'
        QtMocHelpers::SignalData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'triggeredClone'
        QtMocHelpers::SignalData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reloadSettings'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'loadCurrentFile'
        QtMocHelpers::SlotData<void(bool)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'loadCurrentFile'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'fillRenderCache'
        QtMocHelpers::SlotData<void(int)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Slot 'fillRenderCache'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'sideBySide'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'doFindDialog'
        QtMocHelpers::SlotData<void(const QString)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Slot 'doFindDialog'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'doFindAgain'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'goToSource'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleFullScreen'
        QtMocHelpers::SlotData<void(const bool)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 40 },
        }}),
        // Slot 'syncFromSource'
        QtMocHelpers::SlotData<int(const QString &, int, int, PDFDocument::DisplayFlags)>(41, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 5 }, { QMetaType::Int, 42 }, { QMetaType::Int, 43 }, { 0x80000000 | 44, 45 },
        }}),
        // Slot 'syncFromView'
        QtMocHelpers::SlotData<void(const QString &, const QFileInfo &, int)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { 0x80000000 | 11, 12 }, { QMetaType::Int, 13 },
        }}),
        // Slot 'loadFile'
        QtMocHelpers::SlotData<void(const QString &, QFileInfo, PDFDocument::DisplayFlags)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 48 }, { 0x80000000 | 11, 12 }, { 0x80000000 | 44, 45 },
        }}),
        // Slot 'loadFile'
        QtMocHelpers::SlotData<void(const QString &, QFileInfo)>(47, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 48 }, { 0x80000000 | 11, 12 },
        }}),
        // Slot 'loadFile'
        QtMocHelpers::SlotData<void(const QString &)>(47, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 48 },
        }}),
        // Slot 'printPDF'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setAutoHideToolbars'
        QtMocHelpers::SlotData<void(bool)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 51 },
        }}),
        // Slot 'hideToolbars'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showToolbars'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showToolbarsDelayed'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setToolbarIconSize'
        QtMocHelpers::SlotData<void(int)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 56 },
        }}),
        // Slot 'showMessage'
        QtMocHelpers::SlotData<void(const QString &)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 58 },
        }}),
        // Slot 'splitMergeTool'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'fileOpen'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'enablePageActions'
        QtMocHelpers::SlotData<void(int, bool)>(61, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Bool, 2 },
        }}),
        // Slot 'enableZoomActions'
        QtMocHelpers::SlotData<void(qreal)>(62, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Slot 'adjustScaleActions'
        QtMocHelpers::SlotData<void(autoScaleOption)>(63, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 64, 2 },
        }}),
        // Slot 'syncClick'
        QtMocHelpers::SlotData<void(int, const QPointF &, bool)>(65, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 13 }, { 0x80000000 | 66, 67 }, { QMetaType::Bool, 7 },
        }}),
        // Slot 'stopReloadTimer'
        QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'reloadWhenIdle'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'idleReload'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'runExternalViewer'
        QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'runInternalViewer'
        QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleEmbedded'
        QtMocHelpers::SlotData<void()>(73, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleAutoHideToolbars'
        QtMocHelpers::SlotData<void()>(74, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'runQuickBuild'
        QtMocHelpers::SlotData<void()>(75, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setGrid'
        QtMocHelpers::SlotData<void()>(76, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'closeElement'
        QtMocHelpers::SlotData<bool()>(77, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'tileWindows'
        QtMocHelpers::SlotData<void()>(78, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'stackWindows'
        QtMocHelpers::SlotData<void()>(79, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'unminimize'
        QtMocHelpers::SlotData<void()>(80, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateDisplayState'
        QtMocHelpers::SlotData<void(PDFDocument::DisplayFlags)>(81, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 44, 45 },
        }}),
        // Slot 'arrangeWindows'
        QtMocHelpers::SlotData<void(bool)>(82, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 83 },
        }}),
        // Slot 'updateToolBarForOrientation'
        QtMocHelpers::SlotData<void(Qt::Orientation)>(84, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 85, 86 },
        }}),
        // Slot 'jumpToPage'
        QtMocHelpers::SlotData<void()>(87, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'search'
        QtMocHelpers::SlotData<void(bool, bool)>(88, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 89 }, { QMetaType::Bool, 90 },
        }}),
        // Slot 'clearHightlight'
        QtMocHelpers::SlotData<void(bool)>(91, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 92 },
        }}),
        // Slot 'gotoAnnotation'
        QtMocHelpers::SlotData<void(const PDFAnnotation *)>(93, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 94, 95 },
        }}),
        // Slot 'zoomFromAction'
        QtMocHelpers::SlotData<void()>(96, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'zoomSliderChange'
        QtMocHelpers::SlotData<void(int)>(97, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 67 },
        }}),
        // Slot 'zoomSliderChange'
        QtMocHelpers::SlotData<void()>(97, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'enlarge'
        QtMocHelpers::SlotData<void()>(98, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'shrink'
        QtMocHelpers::SlotData<void()>(99, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'fileName'
        QtMocHelpers::MethodData<QString() const>(48, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'getMasterFile'
        QtMocHelpers::MethodData<QFileInfo() const>(100, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Method 'zoomToRight'
        QtMocHelpers::MethodData<void(QWidget *)>(101, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 102, 103 },
        }}),
        // Method 'showPage'
        QtMocHelpers::MethodData<void(int)>(104, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Method 'setResolution'
        QtMocHelpers::MethodData<void(int)>(105, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 106 },
        }}),
        // Method 'goToDestination'
        QtMocHelpers::MethodData<void(const QString &)>(107, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 108 },
        }}),
        // Method 'goToPage'
        QtMocHelpers::MethodData<void(const int)>(109, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Method 'focus'
        QtMocHelpers::MethodData<void()>(110, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'widget'
        QtMocHelpers::MethodData<PDFWidget *()>(111, 2, QMC::AccessPublic, 0x80000000 | 112),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'fileName'
        QtMocHelpers::PropertyData<QString>(48, QMetaType::QString, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PDFDocument, qt_meta_tag_ZN11PDFDocumentE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PDFDocument::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PDFDocumentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PDFDocumentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11PDFDocumentE_t>.metaTypes,
    nullptr
} };

void PDFDocument::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PDFDocument *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->documentClosed(); break;
        case 1: _t->documentLoaded(); break;
        case 2: _t->syncSource((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 3: _t->syncView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 4: _t->focusEditor(); break;
        case 5: _t->fileDropped((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 6: _t->runCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 7: _t->triggeredAbout(); break;
        case 8: _t->triggeredManual(); break;
        case 9: _t->triggeredQuit(); break;
        case 10: _t->triggeredPlaceOnLeft(); break;
        case 11: _t->triggeredConfigure(); break;
        case 12: _t->triggeredEnlarge(); break;
        case 13: _t->triggeredShrink(); break;
        case 14: _t->triggeredClone(); break;
        case 15: _t->reloadSettings(); break;
        case 16: _t->loadCurrentFile((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->loadCurrentFile(); break;
        case 18: _t->fillRenderCache((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->fillRenderCache(); break;
        case 20: _t->sideBySide(); break;
        case 21: _t->doFindDialog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 22: _t->doFindDialog(); break;
        case 23: _t->doFindAgain(); break;
        case 24: _t->goToSource(); break;
        case 25: _t->toggleFullScreen((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 26: { int _r = _t->syncFromSource((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<PDFDocument::DisplayFlags>>(_a[4])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 27: _t->syncFromView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 28: _t->loadFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<PDFDocument::DisplayFlags>>(_a[3]))); break;
        case 29: _t->loadFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[2]))); break;
        case 30: _t->loadFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 31: _t->printPDF(); break;
        case 32: _t->setAutoHideToolbars((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 33: _t->hideToolbars(); break;
        case 34: _t->showToolbars(); break;
        case 35: _t->showToolbarsDelayed(); break;
        case 36: _t->setToolbarIconSize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 37: _t->showMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 38: _t->splitMergeTool(); break;
        case 39: _t->fileOpen(); break;
        case 40: _t->enablePageActions((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 41: _t->enableZoomActions((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 42: _t->adjustScaleActions((*reinterpret_cast<std::add_pointer_t<autoScaleOption>>(_a[1]))); break;
        case 43: _t->syncClick((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 44: _t->stopReloadTimer(); break;
        case 45: _t->reloadWhenIdle(); break;
        case 46: _t->idleReload(); break;
        case 47: _t->runExternalViewer(); break;
        case 48: _t->runInternalViewer(); break;
        case 49: _t->toggleEmbedded(); break;
        case 50: _t->toggleAutoHideToolbars(); break;
        case 51: _t->runQuickBuild(); break;
        case 52: _t->setGrid(); break;
        case 53: { bool _r = _t->closeElement();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 54: _t->tileWindows(); break;
        case 55: _t->stackWindows(); break;
        case 56: _t->unminimize(); break;
        case 57: _t->updateDisplayState((*reinterpret_cast<std::add_pointer_t<PDFDocument::DisplayFlags>>(_a[1]))); break;
        case 58: _t->arrangeWindows((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 59: _t->updateToolBarForOrientation((*reinterpret_cast<std::add_pointer_t<Qt::Orientation>>(_a[1]))); break;
        case 60: _t->jumpToPage(); break;
        case 61: _t->search((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 62: _t->clearHightlight((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 63: _t->gotoAnnotation((*reinterpret_cast<std::add_pointer_t<const PDFAnnotation*>>(_a[1]))); break;
        case 64: _t->zoomFromAction(); break;
        case 65: _t->zoomSliderChange((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 66: _t->zoomSliderChange(); break;
        case 67: _t->enlarge(); break;
        case 68: _t->shrink(); break;
        case 69: { QString _r = _t->fileName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 70: { QFileInfo _r = _t->getMasterFile();
            if (_a[0]) *reinterpret_cast<QFileInfo*>(_a[0]) = std::move(_r); }  break;
        case 71: _t->zoomToRight((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        case 72: _t->showPage((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 73: _t->setResolution((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 74: _t->goToDestination((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 75: _t->goToPage((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 76: _t->focus(); break;
        case 77: { PDFWidget* _r = _t->widget();
            if (_a[0]) *reinterpret_cast<PDFWidget**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QFileInfo >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QFileInfo >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QFileInfo >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QFileInfo >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QFileInfo >(); break;
            }
            break;
        case 71:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PDFDocument::*)()>(_a, &PDFDocument::documentClosed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PDFDocument::*)()>(_a, &PDFDocument::documentLoaded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PDFDocument::*)(const QString & , int , bool , const QString & )>(_a, &PDFDocument::syncSource, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PDFDocument::*)(const QString & , const QFileInfo & , int )>(_a, &PDFDocument::syncView, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PDFDocument::*)()>(_a, &PDFDocument::focusEditor, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PDFDocument::*)(const QUrl & )>(_a, &PDFDocument::fileDropped, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PDFDocument::*)(const QString & , const QFileInfo & , const QFileInfo & , int )>(_a, &PDFDocument::runCommand, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PDFDocument::*)()>(_a, &PDFDocument::triggeredAbout, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (PDFDocument::*)()>(_a, &PDFDocument::triggeredManual, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (PDFDocument::*)()>(_a, &PDFDocument::triggeredQuit, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (PDFDocument::*)()>(_a, &PDFDocument::triggeredPlaceOnLeft, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (PDFDocument::*)()>(_a, &PDFDocument::triggeredConfigure, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (PDFDocument::*)()>(_a, &PDFDocument::triggeredEnlarge, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (PDFDocument::*)()>(_a, &PDFDocument::triggeredShrink, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (PDFDocument::*)()>(_a, &PDFDocument::triggeredClone, 14))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->fileName(); break;
        default: break;
        }
    }
}

const QMetaObject *PDFDocument::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PDFDocument::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PDFDocumentE_t>.strings))
        return static_cast<void*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int PDFDocument::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 78)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 78;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 78)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 78;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void PDFDocument::documentClosed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PDFDocument::documentLoaded()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PDFDocument::syncSource(const QString & _t1, int _t2, bool _t3, const QString & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 3
void PDFDocument::syncView(const QString & _t1, const QFileInfo & _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void PDFDocument::focusEditor()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void PDFDocument::fileDropped(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void PDFDocument::runCommand(const QString & _t1, const QFileInfo & _t2, const QFileInfo & _t3, int _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 7
void PDFDocument::triggeredAbout()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void PDFDocument::triggeredManual()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void PDFDocument::triggeredQuit()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void PDFDocument::triggeredPlaceOnLeft()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void PDFDocument::triggeredConfigure()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void PDFDocument::triggeredEnlarge()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void PDFDocument::triggeredShrink()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void PDFDocument::triggeredClone()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}
QT_WARNING_POP
