/****************************************************************************
** Meta object code from reading C++ file 'searchquery.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../texstudio-4.9.3/src/searchquery.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'searchquery.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11SearchQueryE_t {};
} // unnamed namespace

template <> constexpr inline auto SearchQuery::qt_create_metaobjectdata<qt_meta_tag_ZN11SearchQueryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SearchQuery",
        "runCompleted",
        "",
        "run",
        "LatexDocument*",
        "doc",
        "addDocSearchResult",
        "QDocument*",
        "QList<QDocumentLineHandle*>",
        "search",
        "addFileSearchResult",
        "SearchInfo",
        "setReplacementText",
        "text",
        "replacementText",
        "replaceAll",
        "searchInFilesFinished"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'runCompleted'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'run'
        QtMocHelpers::SlotData<void(LatexDocument *)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'addDocSearchResult'
        QtMocHelpers::SlotData<void(QDocument *, QList<QDocumentLineHandle*>)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 5 }, { 0x80000000 | 8, 9 },
        }}),
        // Slot 'addFileSearchResult'
        QtMocHelpers::SlotData<void(SearchInfo)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 9 },
        }}),
        // Slot 'setReplacementText'
        QtMocHelpers::SlotData<void(QString)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'replacementText'
        QtMocHelpers::SlotData<QString()>(14, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'replaceAll'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'searchInFilesFinished'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SearchQuery, qt_meta_tag_ZN11SearchQueryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SearchQuery::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11SearchQueryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11SearchQueryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11SearchQueryE_t>.metaTypes,
    nullptr
} };

void SearchQuery::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SearchQuery *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->runCompleted(); break;
        case 1: _t->run((*reinterpret_cast<std::add_pointer_t<LatexDocument*>>(_a[1]))); break;
        case 2: _t->addDocSearchResult((*reinterpret_cast<std::add_pointer_t<QDocument*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QDocumentLineHandle*>>>(_a[2]))); break;
        case 3: _t->addFileSearchResult((*reinterpret_cast<std::add_pointer_t<SearchInfo>>(_a[1]))); break;
        case 4: _t->setReplacementText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: { QString _r = _t->replacementText();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->replaceAll(); break;
        case 7: _t->searchInFilesFinished(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDocument* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QDocumentLineHandle*> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SearchQuery::*)()>(_a, &SearchQuery::runCompleted, 0))
            return;
    }
}

const QMetaObject *SearchQuery::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SearchQuery::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11SearchQueryE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SearchQuery::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void SearchQuery::runCompleted()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN16LabelSearchQueryE_t {};
} // unnamed namespace

template <> constexpr inline auto LabelSearchQuery::qt_create_metaobjectdata<qt_meta_tag_ZN16LabelSearchQueryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LabelSearchQuery"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LabelSearchQuery, qt_meta_tag_ZN16LabelSearchQueryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LabelSearchQuery::staticMetaObject = { {
    QMetaObject::SuperData::link<SearchQuery::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16LabelSearchQueryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16LabelSearchQueryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16LabelSearchQueryE_t>.metaTypes,
    nullptr
} };

void LabelSearchQuery::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LabelSearchQuery *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *LabelSearchQuery::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LabelSearchQuery::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16LabelSearchQueryE_t>.strings))
        return static_cast<void*>(this);
    return SearchQuery::qt_metacast(_clname);
}

int LabelSearchQuery::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SearchQuery::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN21SpecialDefSearchQueryE_t {};
} // unnamed namespace

template <> constexpr inline auto SpecialDefSearchQuery::qt_create_metaobjectdata<qt_meta_tag_ZN21SpecialDefSearchQueryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SpecialDefSearchQuery"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SpecialDefSearchQuery, qt_meta_tag_ZN21SpecialDefSearchQueryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SpecialDefSearchQuery::staticMetaObject = { {
    QMetaObject::SuperData::link<SearchQuery::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21SpecialDefSearchQueryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21SpecialDefSearchQueryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21SpecialDefSearchQueryE_t>.metaTypes,
    nullptr
} };

void SpecialDefSearchQuery::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SpecialDefSearchQuery *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *SpecialDefSearchQuery::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SpecialDefSearchQuery::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21SpecialDefSearchQueryE_t>.strings))
        return static_cast<void*>(this);
    return SearchQuery::qt_metacast(_clname);
}

int SpecialDefSearchQuery::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SearchQuery::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
