/****************************************************************************
** Meta object code from reading C++ file 'qsearchreplacepanel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../texstudio-4.9.3/src/qcodeedit/lib/widgets/qsearchreplacepanel.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qsearchreplacepanel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19QSearchReplacePanelE_t {};
} // unnamed namespace

template <> constexpr inline auto QSearchReplacePanel::qt_create_metaobjectdata<qt_meta_tag_ZN19QSearchReplacePanelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QSearchReplacePanel",
        "onClose",
        "",
        "showExtendedSearch",
        "display",
        "mode",
        "replace",
        "closeElement",
        "closeTogether",
        "findNext",
        "findReplace",
        "backward",
        "replaceAll",
        "countOnly",
        "find",
        "text",
        "highlight",
        "regex",
        "word",
        "caseSensitive",
        "fromCursor",
        "selection",
        "selectAllMatches",
        "setOptions",
        "searchOptions",
        "cursor",
        "cFind_textEdited",
        "cReplace_textEdited",
        "on_cbCase_toggled",
        "on",
        "on_cbWords_toggled",
        "on_cbRegExp_toggled",
        "on_cbCursor_toggled",
        "on_cbHighlight_toggled",
        "on_cbSelection_toggled",
        "on_cbEscapeSeq_toggled",
        "on_cbPrompt_toggled",
        "filterChanged",
        "on_bNext_clicked",
        "on_bPrevious_clicked",
        "on_bCount_clicked",
        "on_bReplaceNext_clicked",
        "on_bReplacePrevious_clicked",
        "on_bReplaceAll_clicked",
        "cursorPositionChanged",
        "updateReplacementHint"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'onClose'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showExtendedSearch'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'display'
        QtMocHelpers::SlotData<void(int, bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::Bool, 6 },
        }}),
        // Slot 'closeElement'
        QtMocHelpers::SlotData<void(bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'findNext'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'findReplace'
        QtMocHelpers::SlotData<void(bool, bool, bool, bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 }, { QMetaType::Bool, 6 }, { QMetaType::Bool, 12 }, { QMetaType::Bool, 13 },
        }}),
        // Slot 'findReplace'
        QtMocHelpers::SlotData<void(bool, bool, bool)>(10, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Bool, 11 }, { QMetaType::Bool, 6 }, { QMetaType::Bool, 12 },
        }}),
        // Slot 'findReplace'
        QtMocHelpers::SlotData<void(bool, bool)>(10, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Bool, 11 }, { QMetaType::Bool, 6 },
        }}),
        // Slot 'findReplace'
        QtMocHelpers::SlotData<void(bool)>(10, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'find'
        QtMocHelpers::SlotData<void(QString, bool, bool, bool, bool, bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 }, { QMetaType::Bool, 11 }, { QMetaType::Bool, 16 }, { QMetaType::Bool, 17 },
            { QMetaType::Bool, 18 }, { QMetaType::Bool, 19 },
        }}),
        // Slot 'find'
        QtMocHelpers::SlotData<void(QString, bool, bool, bool, bool, bool, bool, bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 }, { QMetaType::Bool, 11 }, { QMetaType::Bool, 16 }, { QMetaType::Bool, 17 },
            { QMetaType::Bool, 18 }, { QMetaType::Bool, 19 }, { QMetaType::Bool, 20 }, { QMetaType::Bool, 21 },
        }}),
        // Slot 'selectAllMatches'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setOptions'
        QtMocHelpers::SlotData<void(int, bool, bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 24 }, { QMetaType::Bool, 25 }, { QMetaType::Bool, 21 },
        }}),
        // Slot 'cFind_textEdited'
        QtMocHelpers::SlotData<void(const QString &)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'cReplace_textEdited'
        QtMocHelpers::SlotData<void(const QString &)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'on_cbCase_toggled'
        QtMocHelpers::SlotData<void(bool)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 29 },
        }}),
        // Slot 'on_cbWords_toggled'
        QtMocHelpers::SlotData<void(bool)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 29 },
        }}),
        // Slot 'on_cbRegExp_toggled'
        QtMocHelpers::SlotData<void(bool)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 29 },
        }}),
        // Slot 'on_cbCursor_toggled'
        QtMocHelpers::SlotData<void(bool)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 29 },
        }}),
        // Slot 'on_cbHighlight_toggled'
        QtMocHelpers::SlotData<void(bool)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 29 },
        }}),
        // Slot 'on_cbSelection_toggled'
        QtMocHelpers::SlotData<void(bool)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 29 },
        }}),
        // Slot 'on_cbEscapeSeq_toggled'
        QtMocHelpers::SlotData<void(bool)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 29 },
        }}),
        // Slot 'on_cbPrompt_toggled'
        QtMocHelpers::SlotData<void(bool)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 29 },
        }}),
        // Slot 'filterChanged'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_bNext_clicked'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_bPrevious_clicked'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_bCount_clicked'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_bReplaceNext_clicked'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_bReplacePrevious_clicked'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_bReplaceAll_clicked'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'cursorPositionChanged'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateReplacementHint'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QSearchReplacePanel, qt_meta_tag_ZN19QSearchReplacePanelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QSearchReplacePanel::staticMetaObject = { {
    QMetaObject::SuperData::link<QPanel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QSearchReplacePanelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QSearchReplacePanelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19QSearchReplacePanelE_t>.metaTypes,
    nullptr
} };

void QSearchReplacePanel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QSearchReplacePanel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onClose(); break;
        case 1: _t->showExtendedSearch(); break;
        case 2: _t->display((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 3: _t->closeElement((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->findNext(); break;
        case 5: _t->findReplace((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 6: _t->findReplace((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 7: _t->findReplace((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 8: _t->findReplace((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->find((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6]))); break;
        case 10: _t->find((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[8]))); break;
        case 11: _t->selectAllMatches(); break;
        case 12: _t->setOptions((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 13: _t->cFind_textEdited((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->cReplace_textEdited((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->on_cbCase_toggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->on_cbWords_toggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->on_cbRegExp_toggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->on_cbCursor_toggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->on_cbHighlight_toggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->on_cbSelection_toggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->on_cbEscapeSeq_toggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 22: _t->on_cbPrompt_toggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 23: _t->filterChanged(); break;
        case 24: _t->on_bNext_clicked(); break;
        case 25: _t->on_bPrevious_clicked(); break;
        case 26: _t->on_bCount_clicked(); break;
        case 27: _t->on_bReplaceNext_clicked(); break;
        case 28: _t->on_bReplacePrevious_clicked(); break;
        case 29: _t->on_bReplaceAll_clicked(); break;
        case 30: _t->cursorPositionChanged(); break;
        case 31: _t->updateReplacementHint(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QSearchReplacePanel::*)()>(_a, &QSearchReplacePanel::onClose, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QSearchReplacePanel::*)()>(_a, &QSearchReplacePanel::showExtendedSearch, 1))
            return;
    }
}

const QMetaObject *QSearchReplacePanel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QSearchReplacePanel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QSearchReplacePanelE_t>.strings))
        return static_cast<void*>(this);
    return QPanel::qt_metacast(_clname);
}

int QSearchReplacePanel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QPanel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 32;
    }
    return _id;
}

// SIGNAL 0
void QSearchReplacePanel::onClose()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QSearchReplacePanel::showExtendedSearch()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
