/****************************************************************************
** Meta object code from reading C++ file 'txstabwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../texstudio-4.9.3/src/txstabwidget.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'txstabwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12TxsTabWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto TxsTabWidget::qt_create_metaobjectdata<qt_meta_tag_ZN12TxsTabWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TxsTabWidget",
        "tabMoved",
        "",
        "from",
        "to",
        "tabBarContextMenuRequested",
        "QPoint",
        "point",
        "editorAboutToChangeByTabClick",
        "LatexEditorView*",
        "closeEditorRequested",
        "edView",
        "currentEditorChanged",
        "activationRequested",
        "gotoNextDocument",
        "gotoPrevDocument",
        "gotoFirstDocument",
        "gotoLastDocument",
        "insertEditor",
        "pos",
        "asCurrent",
        "removeEditor",
        "updateTabFromSender",
        "currentTabAboutToChange",
        "onTabCloseRequest",
        "i"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'tabMoved'
        QtMocHelpers::SignalData<void(int, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 },
        }}),
        // Signal 'tabBarContextMenuRequested'
        QtMocHelpers::SignalData<void(QPoint)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'editorAboutToChangeByTabClick'
        QtMocHelpers::SignalData<void(LatexEditorView *, LatexEditorView *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 3 }, { 0x80000000 | 9, 4 },
        }}),
        // Signal 'closeEditorRequested'
        QtMocHelpers::SignalData<void(LatexEditorView *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 11 },
        }}),
        // Signal 'currentEditorChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activationRequested'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'gotoNextDocument'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'gotoPrevDocument'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'gotoFirstDocument'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'gotoLastDocument'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertEditor'
        QtMocHelpers::SlotData<void(LatexEditorView *, int, bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 11 }, { QMetaType::Int, 19 }, { QMetaType::Bool, 20 },
        }}),
        // Slot 'insertEditor'
        QtMocHelpers::SlotData<void(LatexEditorView *, int)>(18, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 9, 11 }, { QMetaType::Int, 19 },
        }}),
        // Slot 'insertEditor'
        QtMocHelpers::SlotData<void(LatexEditorView *)>(18, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 9, 11 },
        }}),
        // Slot 'removeEditor'
        QtMocHelpers::SlotData<void(LatexEditorView *)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 11 },
        }}),
        // Slot 'updateTabFromSender'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'currentTabAboutToChange'
        QtMocHelpers::SlotData<void(int, int)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 },
        }}),
        // Slot 'onTabCloseRequest'
        QtMocHelpers::SlotData<void(int)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 25 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TxsTabWidget, qt_meta_tag_ZN12TxsTabWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TxsTabWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QTabWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12TxsTabWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12TxsTabWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12TxsTabWidgetE_t>.metaTypes,
    nullptr
} };

void TxsTabWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TxsTabWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->tabMoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->tabBarContextMenuRequested((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 2: _t->editorAboutToChangeByTabClick((*reinterpret_cast<std::add_pointer_t<LatexEditorView*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<LatexEditorView*>>(_a[2]))); break;
        case 3: _t->closeEditorRequested((*reinterpret_cast<std::add_pointer_t<LatexEditorView*>>(_a[1]))); break;
        case 4: _t->currentEditorChanged(); break;
        case 5: _t->activationRequested(); break;
        case 6: _t->gotoNextDocument(); break;
        case 7: _t->gotoPrevDocument(); break;
        case 8: _t->gotoFirstDocument(); break;
        case 9: _t->gotoLastDocument(); break;
        case 10: _t->insertEditor((*reinterpret_cast<std::add_pointer_t<LatexEditorView*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 11: _t->insertEditor((*reinterpret_cast<std::add_pointer_t<LatexEditorView*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 12: _t->insertEditor((*reinterpret_cast<std::add_pointer_t<LatexEditorView*>>(_a[1]))); break;
        case 13: _t->removeEditor((*reinterpret_cast<std::add_pointer_t<LatexEditorView*>>(_a[1]))); break;
        case 14: _t->updateTabFromSender(); break;
        case 15: _t->currentTabAboutToChange((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 16: _t->onTabCloseRequest((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TxsTabWidget::*)(int , int )>(_a, &TxsTabWidget::tabMoved, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TxsTabWidget::*)(QPoint )>(_a, &TxsTabWidget::tabBarContextMenuRequested, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TxsTabWidget::*)(LatexEditorView * , LatexEditorView * )>(_a, &TxsTabWidget::editorAboutToChangeByTabClick, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TxsTabWidget::*)(LatexEditorView * )>(_a, &TxsTabWidget::closeEditorRequested, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TxsTabWidget::*)()>(_a, &TxsTabWidget::currentEditorChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TxsTabWidget::*)()>(_a, &TxsTabWidget::activationRequested, 5))
            return;
    }
}

const QMetaObject *TxsTabWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TxsTabWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12TxsTabWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QTabWidget::qt_metacast(_clname);
}

int TxsTabWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTabWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void TxsTabWidget::tabMoved(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void TxsTabWidget::tabBarContextMenuRequested(QPoint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void TxsTabWidget::editorAboutToChangeByTabClick(LatexEditorView * _t1, LatexEditorView * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void TxsTabWidget::closeEditorRequested(LatexEditorView * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void TxsTabWidget::currentEditorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void TxsTabWidget::activationRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
namespace {
struct qt_meta_tag_ZN17ChangeAwareTabBarE_t {};
} // unnamed namespace

template <> constexpr inline auto ChangeAwareTabBar::qt_create_metaobjectdata<qt_meta_tag_ZN17ChangeAwareTabBarE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ChangeAwareTabBar",
        "currentTabAboutToChange",
        "",
        "from",
        "to",
        "tabLeftClicked",
        "middleMouseButtonPressed",
        "tabNr"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentTabAboutToChange'
        QtMocHelpers::SignalData<void(int, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 },
        }}),
        // Signal 'tabLeftClicked'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'middleMouseButtonPressed'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ChangeAwareTabBar, qt_meta_tag_ZN17ChangeAwareTabBarE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ChangeAwareTabBar::staticMetaObject = { {
    QMetaObject::SuperData::link<QTabBar::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ChangeAwareTabBarE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ChangeAwareTabBarE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17ChangeAwareTabBarE_t>.metaTypes,
    nullptr
} };

void ChangeAwareTabBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ChangeAwareTabBar *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentTabAboutToChange((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->tabLeftClicked(); break;
        case 2: _t->middleMouseButtonPressed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ChangeAwareTabBar::*)(int , int )>(_a, &ChangeAwareTabBar::currentTabAboutToChange, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ChangeAwareTabBar::*)()>(_a, &ChangeAwareTabBar::tabLeftClicked, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ChangeAwareTabBar::*)(int )>(_a, &ChangeAwareTabBar::middleMouseButtonPressed, 2))
            return;
    }
}

const QMetaObject *ChangeAwareTabBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ChangeAwareTabBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ChangeAwareTabBarE_t>.strings))
        return static_cast<void*>(this);
    return QTabBar::qt_metacast(_clname);
}

int ChangeAwareTabBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTabBar::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void ChangeAwareTabBar::currentTabAboutToChange(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void ChangeAwareTabBar::tabLeftClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ChangeAwareTabBar::middleMouseButtonPressed(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
