/****************************************************************************
** Meta object code from reading C++ file 'cursorhistory.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../texstudio-4.9.3/src/cursorhistory.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'cursorhistory.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13CursorHistoryE_t {};
} // unnamed namespace

template <> constexpr inline auto CursorHistory::qt_create_metaobjectdata<qt_meta_tag_ZN13CursorHistoryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CursorHistory",
        "back",
        "QDocumentCursor",
        "",
        "currentCursor",
        "forward",
        "aboutToDeleteDoc",
        "LatexDocument*",
        "doc",
        "documentClosed",
        "obj",
        "lineDeleted",
        "QDocumentLineHandle*",
        "dlh",
        "hint"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'back'
        QtMocHelpers::SlotData<QDocumentCursor(const QDocumentCursor &)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 2, 4 },
        }}),
        // Slot 'back'
        QtMocHelpers::SlotData<QDocumentCursor()>(1, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 2),
        // Slot 'forward'
        QtMocHelpers::SlotData<QDocumentCursor(const QDocumentCursor &)>(5, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 2, 4 },
        }}),
        // Slot 'forward'
        QtMocHelpers::SlotData<QDocumentCursor()>(5, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 2),
        // Slot 'aboutToDeleteDoc'
        QtMocHelpers::SlotData<void(LatexDocument *)>(6, 3, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'documentClosed'
        QtMocHelpers::SlotData<void(QObject *)>(9, 3, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 10 },
        }}),
        // Slot 'lineDeleted'
        QtMocHelpers::SlotData<void(QDocumentLineHandle *, int)>(11, 3, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { QMetaType::Int, 14 },
        }}),
        // Slot 'lineDeleted'
        QtMocHelpers::SlotData<void(QDocumentLineHandle *)>(11, 3, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CursorHistory, qt_meta_tag_ZN13CursorHistoryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CursorHistory::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13CursorHistoryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13CursorHistoryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13CursorHistoryE_t>.metaTypes,
    nullptr
} };

void CursorHistory::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CursorHistory *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDocumentCursor _r = _t->back((*reinterpret_cast<std::add_pointer_t<QDocumentCursor>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDocumentCursor*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDocumentCursor _r = _t->back();
            if (_a[0]) *reinterpret_cast<QDocumentCursor*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDocumentCursor _r = _t->forward((*reinterpret_cast<std::add_pointer_t<QDocumentCursor>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDocumentCursor*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDocumentCursor _r = _t->forward();
            if (_a[0]) *reinterpret_cast<QDocumentCursor*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->aboutToDeleteDoc((*reinterpret_cast<std::add_pointer_t<LatexDocument*>>(_a[1]))); break;
        case 5: _t->documentClosed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 6: _t->lineDeleted((*reinterpret_cast<std::add_pointer_t<QDocumentLineHandle*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 7: _t->lineDeleted((*reinterpret_cast<std::add_pointer_t<QDocumentLineHandle*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDocumentCursor >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDocumentCursor >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< LatexDocument* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDocumentLineHandle* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDocumentLineHandle* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *CursorHistory::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CursorHistory::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13CursorHistoryE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int CursorHistory::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
