/****************************************************************************
** Meta object code from reading C++ file 'qlinemarksinfocenter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../texstudio-4.9.3/src/qcodeedit/lib/qlinemarksinfocenter.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qlinemarksinfocenter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20QLineMarksInfoCenterE_t {};
} // unnamed namespace

template <> constexpr inline auto QLineMarksInfoCenter::qt_create_metaobjectdata<qt_meta_tag_ZN20QLineMarksInfoCenterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QLineMarksInfoCenter",
        "lineMarkAdded",
        "",
        "QLineMark",
        "mark",
        "lineMarkRemoved",
        "loadMarks",
        "f",
        "saveMarks",
        "loadMarkTypes",
        "clear",
        "removeMarks",
        "file",
        "addLineMark",
        "toggleLineMark",
        "removeLineMark",
        "QLineMarkHandle",
        "flush",
        "cursorMoved",
        "QEditor*",
        "e",
        "lineDeleted",
        "QDocumentLineHandle*",
        "h",
        "hint",
        "markChanged",
        "on"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'lineMarkAdded'
        QtMocHelpers::SignalData<void(const QLineMark &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'lineMarkRemoved'
        QtMocHelpers::SignalData<void(const QLineMark &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'loadMarks'
        QtMocHelpers::SlotData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'saveMarks'
        QtMocHelpers::SlotData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'loadMarkTypes'
        QtMocHelpers::SlotData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'clear'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'removeMarks'
        QtMocHelpers::SlotData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'addLineMark'
        QtMocHelpers::SlotData<void(const QLineMark &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'toggleLineMark'
        QtMocHelpers::SlotData<void(const QLineMark &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'removeLineMark'
        QtMocHelpers::SlotData<void(const QLineMark &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'addLineMark'
        QtMocHelpers::SlotData<void(const QLineMarkHandle &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 4 },
        }}),
        // Slot 'toggleLineMark'
        QtMocHelpers::SlotData<void(const QLineMarkHandle &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 4 },
        }}),
        // Slot 'removeLineMark'
        QtMocHelpers::SlotData<void(const QLineMarkHandle &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 4 },
        }}),
        // Slot 'flush'
        QtMocHelpers::SlotData<void(const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'cursorMoved'
        QtMocHelpers::SlotData<void(QEditor *)>(18, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'lineDeleted'
        QtMocHelpers::SlotData<void(QDocumentLineHandle *, int)>(21, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { QMetaType::Int, 24 },
        }}),
        // Slot 'lineDeleted'
        QtMocHelpers::SlotData<void(QDocumentLineHandle *)>(21, 2, QMC::AccessProtected | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'markChanged'
        QtMocHelpers::SlotData<void(const QString &, QDocumentLineHandle *, int, bool)>(25, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { 0x80000000 | 22, 23 }, { QMetaType::Int, 4 }, { QMetaType::Bool, 26 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QLineMarksInfoCenter, qt_meta_tag_ZN20QLineMarksInfoCenterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QLineMarksInfoCenter::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20QLineMarksInfoCenterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20QLineMarksInfoCenterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20QLineMarksInfoCenterE_t>.metaTypes,
    nullptr
} };

void QLineMarksInfoCenter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QLineMarksInfoCenter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->lineMarkAdded((*reinterpret_cast<std::add_pointer_t<QLineMark>>(_a[1]))); break;
        case 1: _t->lineMarkRemoved((*reinterpret_cast<std::add_pointer_t<QLineMark>>(_a[1]))); break;
        case 2: _t->loadMarks((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->saveMarks((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->loadMarkTypes((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->clear(); break;
        case 6: _t->removeMarks((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->addLineMark((*reinterpret_cast<std::add_pointer_t<QLineMark>>(_a[1]))); break;
        case 8: _t->toggleLineMark((*reinterpret_cast<std::add_pointer_t<QLineMark>>(_a[1]))); break;
        case 9: _t->removeLineMark((*reinterpret_cast<std::add_pointer_t<QLineMark>>(_a[1]))); break;
        case 10: _t->addLineMark((*reinterpret_cast<std::add_pointer_t<QLineMarkHandle>>(_a[1]))); break;
        case 11: _t->toggleLineMark((*reinterpret_cast<std::add_pointer_t<QLineMarkHandle>>(_a[1]))); break;
        case 12: _t->removeLineMark((*reinterpret_cast<std::add_pointer_t<QLineMarkHandle>>(_a[1]))); break;
        case 13: _t->flush((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->cursorMoved((*reinterpret_cast<std::add_pointer_t<QEditor*>>(_a[1]))); break;
        case 15: _t->lineDeleted((*reinterpret_cast<std::add_pointer_t<QDocumentLineHandle*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 16: _t->lineDeleted((*reinterpret_cast<std::add_pointer_t<QDocumentLineHandle*>>(_a[1]))); break;
        case 17: _t->markChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDocumentLineHandle*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QLineMark >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QLineMark >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QLineMark >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QLineMark >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QLineMark >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QLineMarkHandle >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QLineMarkHandle >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QLineMarkHandle >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QLineMarksInfoCenter::*)(const QLineMark & )>(_a, &QLineMarksInfoCenter::lineMarkAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QLineMarksInfoCenter::*)(const QLineMark & )>(_a, &QLineMarksInfoCenter::lineMarkRemoved, 1))
            return;
    }
}

const QMetaObject *QLineMarksInfoCenter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QLineMarksInfoCenter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20QLineMarksInfoCenterE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QLineMarksInfoCenter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void QLineMarksInfoCenter::lineMarkAdded(const QLineMark & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void QLineMarksInfoCenter::lineMarkRemoved(const QLineMark & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
