/******************************************************************************
 * Do not manually edit this file. It is automatically generated by a call to
 * texstudio --update-translations
 * This generates some additional translations which lupdate doesn't find
 * (e.g. from uiconfig.xml, color names, qnfa format names and tags) 
 ******************************************************************************/
#undef UNDEFINED
#ifdef UNDEFINED
static const char* translations[] = {
QT_TRANSLATE_NOOP("ConfigManager", "&LaTeX"), 
QT_TRANSLATE_NOOP("ConfigManager", "&Sectioning"), 
QT_TRANSLATE_NOOP("ConfigManager", "&Environments"), 
QT_TRANSLATE_NOOP("ConfigManager", "&List Environments"), 
QT_TRANSLATE_NOOP("ConfigManager", "Boxes"), 
QT_TRANSLATE_NOOP("ConfigManager", "Font St&yles"), 
QT_TRANSLATE_NOOP("ConfigManager", "Font Sizes"), 
QT_TRANSLATE_NOOP("ConfigManager", "&Tabular Environment"), 
QT_TRANSLATE_NOOP("ConfigManager", "&Horizontal Spacing"), 
QT_TRANSLATE_NOOP("ConfigManager", "&Vertical Spacing"), 
QT_TRANSLATE_NOOP("ConfigManager", "International &Accents"), 
QT_TRANSLATE_NOOP("ConfigManager", "Input/Include &Files"), 
QT_TRANSLATE_NOOP("ConfigManager", "Review remarks (changes)"), 
QT_TRANSLATE_NOOP("ConfigManager", "Cross References"), 
QT_TRANSLATE_NOOP("ConfigManager", "Bibliography"), 
QT_TRANSLATE_NOOP("ConfigManager", "&Math"), 
QT_TRANSLATE_NOOP("ConfigManager", "Math &Equations"), 
QT_TRANSLATE_NOOP("ConfigManager", "Math &Functions"), 
QT_TRANSLATE_NOOP("ConfigManager", "Math &Definitions"), 
QT_TRANSLATE_NOOP("ConfigManager", "Math Font St&yles"), 
QT_TRANSLATE_NOOP("ConfigManager", "Math &Stacking Symbols"), 
QT_TRANSLATE_NOOP("ConfigManager", "Math &Accents"), 
QT_TRANSLATE_NOOP("ConfigManager", "Math S&paces"), 
QT_TRANSLATE_NOOP("ConfigManager", "AMS packages"), 
QT_TRANSLATE_NOOP("ConfigManager", "The main American Mathematical Society packages"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\begin{document}"), 
QT_TRANSLATE_NOOP("ConfigManager", "Text is allowed only between \\begin{document} and \\end{document}."), 
QT_TRANSLATE_NOOP("ConfigManager", "The \\title command declares text to be the title."), 
QT_TRANSLATE_NOOP("ConfigManager", "The \\author command declares the author(s), where names is a list of authors separated by \\and commands."), 
QT_TRANSLATE_NOOP("ConfigManager", "If used, the \\date command declares the date, either with explicit arg for explicit date or with empty arg for no date. If not used, the current date will automatically be inserted by \\maketitle."), 
QT_TRANSLATE_NOOP("ConfigManager", "This command generates a title on a separate title page%n- except in the article class, where the title normally goes at the top of the first page."), 
QT_TRANSLATE_NOOP("ConfigManager", "Put this command where you want the table of contents to go"), 
QT_TRANSLATE_NOOP("ConfigManager", "part"), 
QT_TRANSLATE_NOOP("ConfigManager", "chapter"), 
QT_TRANSLATE_NOOP("ConfigManager", "section"), 
QT_TRANSLATE_NOOP("ConfigManager", "subsection"), 
QT_TRANSLATE_NOOP("ConfigManager", "subsubsection"), 
QT_TRANSLATE_NOOP("ConfigManager", "paragraph"), 
QT_TRANSLATE_NOOP("ConfigManager", "subparagraph"), 
QT_TRANSLATE_NOOP("ConfigManager", "part*"), 
QT_TRANSLATE_NOOP("ConfigManager", "chapter*"), 
QT_TRANSLATE_NOOP("ConfigManager", "section*"), 
QT_TRANSLATE_NOOP("ConfigManager", "subsection*"), 
QT_TRANSLATE_NOOP("ConfigManager", "subsubsection*"), 
QT_TRANSLATE_NOOP("ConfigManager", "paragraph*"), 
QT_TRANSLATE_NOOP("ConfigManager", "subparagraph*"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\begin{<environment>}"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\begin{center}"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\begin{flushleft}"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\begin{flushright}"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\begin{quote}"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\begin{quotation}"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\begin{verse}"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\begin{verbatim}"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\begin{table}"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\begin{figure}"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\begin{titlepage}"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\begin{itemize}"), 
QT_TRANSLATE_NOOP("ConfigManager", "The itemize environment produces a 'bulleted' list.%nEach item of an itemized list begins with an \\item command."), 
QT_TRANSLATE_NOOP("ConfigManager", "\\begin{enumerate}"), 
QT_TRANSLATE_NOOP("ConfigManager", "The enumerate environment produces a numbered list.%nEach item of an enumerated list begins with an \\item command."), 
QT_TRANSLATE_NOOP("ConfigManager", "\\begin{description}"), 
QT_TRANSLATE_NOOP("ConfigManager", "The description environment produces a labelled list.%nEach item of the list begins with an \\item[label] command."), 
QT_TRANSLATE_NOOP("ConfigManager", "\\begin{list}"), 
QT_TRANSLATE_NOOP("ConfigManager", "The {label} argument is a piece of text that is inserted in a box to form the label.%nThe {spacing} argument contains commands to change the spacing parameters for the list.%nEach item of the list begins with an \\item command."), 
QT_TRANSLATE_NOOP("ConfigManager", "\\item[label] Hello"), 
QT_TRANSLATE_NOOP("ConfigManager", "mbox"), 
QT_TRANSLATE_NOOP("ConfigManager", "makebox"), 
QT_TRANSLATE_NOOP("ConfigManager", "fbox"), 
QT_TRANSLATE_NOOP("ConfigManager", "framebox"), 
QT_TRANSLATE_NOOP("ConfigManager", "newsavebox"), 
QT_TRANSLATE_NOOP("ConfigManager", "sbox"), 
QT_TRANSLATE_NOOP("ConfigManager", "savebox"), 
QT_TRANSLATE_NOOP("ConfigManager", "usebox"), 
QT_TRANSLATE_NOOP("ConfigManager", "raisebox"), 
QT_TRANSLATE_NOOP("ConfigManager", "parbox"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\begin{minipage}"), 
QT_TRANSLATE_NOOP("ConfigManager", "rule"), 
QT_TRANSLATE_NOOP("ConfigManager", "Emphasis - \\emph"), 
QT_TRANSLATE_NOOP("ConfigManager", "Italics - \\textit"), 
QT_TRANSLATE_NOOP("ConfigManager", "Slanted - \\textsl"), 
QT_TRANSLATE_NOOP("ConfigManager", "Boldface - \\textbf"), 
QT_TRANSLATE_NOOP("ConfigManager", "Typewriter - \\texttt"), 
QT_TRANSLATE_NOOP("ConfigManager", "Small Caps - \\textsc"), 
QT_TRANSLATE_NOOP("ConfigManager", "Sans Serif - \\textsf"), 
QT_TRANSLATE_NOOP("ConfigManager", "Underline - \\underline"), 
QT_TRANSLATE_NOOP("ConfigManager", "tiny"), 
QT_TRANSLATE_NOOP("ConfigManager", "scriptsize"), 
QT_TRANSLATE_NOOP("ConfigManager", "footnotesize"), 
QT_TRANSLATE_NOOP("ConfigManager", "small"), 
QT_TRANSLATE_NOOP("ConfigManager", "normalsize"), 
QT_TRANSLATE_NOOP("ConfigManager", "large"), 
QT_TRANSLATE_NOOP("ConfigManager", "Large"), 
QT_TRANSLATE_NOOP("ConfigManager", "LARGE"), 
QT_TRANSLATE_NOOP("ConfigManager", "huge"), 
QT_TRANSLATE_NOOP("ConfigManager", "Huge"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\begin{tabbing}"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\begin{tabbing}%ntext \\= more text \\= still more text \\= last text \\\\%nsecond row \\>  \\> more \\\\%n\\end{tabbing}"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\begin{tabular}"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\begin{tabular}[pos]{cols}%ncolumn 1 entry & column 2 entry ... & column n entry \\\\%n...%n\\end{tabular}"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\multicolumn{cols}{pos}{text}%ncol, specifies the number of columns to span.%npos specifies the formatting of the entry: c for centred, l for flushleft, r for flushright.%ntext specifies what text is to make up the entry."), 
QT_TRANSLATE_NOOP("ConfigManager", "The \\hline command draws a horizontal line the width of the table."), 
QT_TRANSLATE_NOOP("ConfigManager", "The \\vline command draws a vertical line extending the full height and depth of its row."), 
QT_TRANSLATE_NOOP("ConfigManager", "The command \\space gives you a space where you can't enter a space character."), 
QT_TRANSLATE_NOOP("ConfigManager", "The \\enspace command inserts a horizontal space of 1/2em."), 
QT_TRANSLATE_NOOP("ConfigManager", "The \\quad command inserts a horizontal space of 1em (1em being the width of M)."), 
QT_TRANSLATE_NOOP("ConfigManager", "The \\qquad command inserts a horizontal space of 2em."), 
QT_TRANSLATE_NOOP("ConfigManager", "The command \\thinspace produces unbreakable and unstretchable space of 1/6em (same as \\, in math mode)."), 
QT_TRANSLATE_NOOP("ConfigManager", "The command \\negthinspace produces unbreakable and unstretchable space of -1/6em (same as \\, in math mode)."), 
QT_TRANSLATE_NOOP("ConfigManager", "The \\hspace command inserts an amount of skip of horizontal space."), 
QT_TRANSLATE_NOOP("ConfigManager", "The \\hfill command inserts a rubber length which has no natural space but that can stretch horizontally as far as needed."), 
QT_TRANSLATE_NOOP("ConfigManager", "The \\hrulefill command produces an infinite horizontal rubber length that LaTeX fills with a rule (that is, a line), instead of white space."), 
QT_TRANSLATE_NOOP("ConfigManager", "The \\dotfill command produces an infinite horizontal rubber length that LaTeX fills with dots, instead of white space."), 
QT_TRANSLATE_NOOP("ConfigManager", "The \\newpage command ends the current page"), 
QT_TRANSLATE_NOOP("ConfigManager", "The \\linebreak command tells LaTeX to break the current line at the point of the command."), 
QT_TRANSLATE_NOOP("ConfigManager", "The \\pagebreak command tells LaTeX to break the current page at the point of the command."), 
QT_TRANSLATE_NOOP("ConfigManager", "The \\bigskip command adds a 'big' vertical space."), 
QT_TRANSLATE_NOOP("ConfigManager", "The \\medskip command adds a 'medium' vertical space."), 
QT_TRANSLATE_NOOP("ConfigManager", "The \\smallskip command adds a 'small' vertical space."), 
QT_TRANSLATE_NOOP("ConfigManager", "The \\vspace command inserts an amount of skip (positive, zero or negative) of vertical space."), 
QT_TRANSLATE_NOOP("ConfigManager", "The \\vfill command inserts a rubber length which has no natural space but that can stretch vertically as far as needed."), 
QT_TRANSLATE_NOOP("ConfigManager", "New line - \\\\"), 
QT_TRANSLATE_NOOP("ConfigManager", "The \\newline command breaks the line right where it is."), 
QT_TRANSLATE_NOOP("ConfigManager", "\\input{file}"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\include{file}"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\includeonly{filelist}"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\includegraphics{file}"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\highlight{text} (changes)"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\comment{comment} (changes)"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\added{text} (changes)"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\deleted{text} (changes)"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\replaced{text}{replacement} (changes)"), 
QT_TRANSLATE_NOOP("ConfigManager", "label"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\label{key}"), 
QT_TRANSLATE_NOOP("ConfigManager", "index"), 
QT_TRANSLATE_NOOP("ConfigManager", "cite"), 
QT_TRANSLATE_NOOP("ConfigManager", "This command generates an in-text citation to the reference associated with the ref entry in the bib file"), 
QT_TRANSLATE_NOOP("ConfigManager", "footnote"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\footnote[number]{text}%nThe \\footnote command places the numbered footnote text at the bottom of the current page."), 
QT_TRANSLATE_NOOP("ConfigManager", "The argument to \\bibliographystyle refers to a file style.bst, which defines how your citations will look"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\addbibresource{bibfile} specifies the location of a resource file for biblatex such as a .bib file. The filename should contain the extension (e.g. '\\addbibresource{mybibliography.bib}'). You can only add one file per \\addbibresource{} command (no comma-separated lists allowed). But you can use multiple commands."), 
QT_TRANSLATE_NOOP("ConfigManager", "Inline math - $...$"), 
QT_TRANSLATE_NOOP("ConfigManager", "Math (in text style) within a paragraph of text"), 
QT_TRANSLATE_NOOP("ConfigManager", "Inline math - \\(...\\)"), 
QT_TRANSLATE_NOOP("ConfigManager", "Same as $...$ and the math environment"), 
QT_TRANSLATE_NOOP("ConfigManager", "Display math - \\[...\\]"), 
QT_TRANSLATE_NOOP("ConfigManager", "Math (in display style) apart from paragraph of text"), 
QT_TRANSLATE_NOOP("ConfigManager", "Subscript - _{}"), 
QT_TRANSLATE_NOOP("ConfigManager", "Superscript - ^{}"), 
QT_TRANSLATE_NOOP("ConfigManager", "Fraction - \\frac{}{}"), 
QT_TRANSLATE_NOOP("CodeSnippet_PlaceHolder", "num"), 
QT_TRANSLATE_NOOP("CodeSnippet_PlaceHolder", "den"), 
QT_TRANSLATE_NOOP("ConfigManager", "Fraction - \\dfrac{}{}"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\dfrac (amsmath) always uses display style for the fraction"), 
QT_TRANSLATE_NOOP("CodeSnippet_PlaceHolder", "num"), 
QT_TRANSLATE_NOOP("CodeSnippet_PlaceHolder", "den"), 
QT_TRANSLATE_NOOP("ConfigManager", "Square Root - \\sqrt{}"), 
QT_TRANSLATE_NOOP("ConfigManager", "Autosize opening delimiter"), 
QT_TRANSLATE_NOOP("ConfigManager", "Autosize closing delimiter"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\begin{array}...\\end{array}"), 
QT_TRANSLATE_NOOP("ConfigManager", "Tabular for math (used inside one of the other math environments)"), 
QT_TRANSLATE_NOOP("ConfigManager", "env equation"), 
QT_TRANSLATE_NOOP("ConfigManager", "Single equation centered in a row"), 
QT_TRANSLATE_NOOP("ConfigManager", "env align (amsmath)"), 
QT_TRANSLATE_NOOP("ConfigManager", "Multiple equations aligned within columns"), 
QT_TRANSLATE_NOOP("ConfigManager", "env alignat (amsmath)"), 
QT_TRANSLATE_NOOP("ConfigManager", "Multiple equations aligned within columns with customizable column spacing"), 
QT_TRANSLATE_NOOP("ConfigManager", "env flalign (amsmath)"), 
QT_TRANSLATE_NOOP("ConfigManager", "Multiple equations aligned within columns having column spacing to fill full line"), 
QT_TRANSLATE_NOOP("ConfigManager", "env gather (amsmath)"), 
QT_TRANSLATE_NOOP("ConfigManager", "Multiple equations centered in rows"), 
QT_TRANSLATE_NOOP("ConfigManager", "env multline (amsmath)"), 
QT_TRANSLATE_NOOP("ConfigManager", "Single equation split into multiple lines"), 
QT_TRANSLATE_NOOP("ConfigManager", "env equation* (amsmath)"), 
QT_TRANSLATE_NOOP("ConfigManager", "The equation* environment is an unnumbered equation environment."), 
QT_TRANSLATE_NOOP("ConfigManager", "env align* (amsmath)"), 
QT_TRANSLATE_NOOP("ConfigManager", "The align* environment is an unnumbered align environment."), 
QT_TRANSLATE_NOOP("ConfigManager", "env alignat* (amsmath)"), 
QT_TRANSLATE_NOOP("ConfigManager", "The alignat* environment is an unnumbered alignat environment."), 
QT_TRANSLATE_NOOP("ConfigManager", "env flalign* (amsmath)"), 
QT_TRANSLATE_NOOP("ConfigManager", "The flalign* environment is an unnumbered flalign environment."), 
QT_TRANSLATE_NOOP("ConfigManager", "env gather* (amsmath)"), 
QT_TRANSLATE_NOOP("ConfigManager", "The gather* environment is an unnumbered gather environment."), 
QT_TRANSLATE_NOOP("ConfigManager", "env multline* (amsmath)"), 
QT_TRANSLATE_NOOP("ConfigManager", "The multline* environment is an unnumbered multline environment."), 
QT_TRANSLATE_NOOP("ConfigManager", "env cases (amsmath)"), 
QT_TRANSLATE_NOOP("ConfigManager", "Distinction of cases (within other math env)"), 
QT_TRANSLATE_NOOP("ConfigManager", "env split (amsmath)"), 
QT_TRANSLATE_NOOP("ConfigManager", "Single equation split into multiple aligned lines (within other math env)"), 
QT_TRANSLATE_NOOP("ConfigManager", "env Corollary (ntheorem)"), 
QT_TRANSLATE_NOOP("ConfigManager", "Needs \\usepackage[standard]{ntheorem}"), 
QT_TRANSLATE_NOOP("ConfigManager", "env Definition (ntheorem)"), 
QT_TRANSLATE_NOOP("ConfigManager", "Needs \\usepackage[standard]{ntheorem}"), 
QT_TRANSLATE_NOOP("ConfigManager", "env Example (ntheorem)"), 
QT_TRANSLATE_NOOP("ConfigManager", "Needs \\usepackage[standard]{ntheorem}"), 
QT_TRANSLATE_NOOP("ConfigManager", "env Lemma (ntheorem)"), 
QT_TRANSLATE_NOOP("ConfigManager", "Needs \\usepackage[standard]{ntheorem}"), 
QT_TRANSLATE_NOOP("ConfigManager", "env Proof (ntheorem)"), 
QT_TRANSLATE_NOOP("ConfigManager", "Needs \\usepackage[standard]{ntheorem}"), 
QT_TRANSLATE_NOOP("ConfigManager", "env Proposition (ntheorem)"), 
QT_TRANSLATE_NOOP("ConfigManager", "Needs \\usepackage[standard]{ntheorem}"), 
QT_TRANSLATE_NOOP("ConfigManager", "env Remark (ntheorem)"), 
QT_TRANSLATE_NOOP("ConfigManager", "Needs \\usepackage[standard]{ntheorem}"), 
QT_TRANSLATE_NOOP("ConfigManager", "env Theorem (ntheorem)"), 
QT_TRANSLATE_NOOP("ConfigManager", "Needs \\usepackage[standard]{ntheorem}"), 
QT_TRANSLATE_NOOP("ConfigManager", "Roman - \\mathrm{}"), 
QT_TRANSLATE_NOOP("ConfigManager", "Italic - \\mathit{}"), 
QT_TRANSLATE_NOOP("ConfigManager", "Bold - \\mathbf{}"), 
QT_TRANSLATE_NOOP("ConfigManager", "Sans Serif - \\mathsf{}"), 
QT_TRANSLATE_NOOP("ConfigManager", "Typewriter - \\mathtt{}"), 
QT_TRANSLATE_NOOP("ConfigManager", "Calligraphic - \\mathcal{}"), 
QT_TRANSLATE_NOOP("ConfigManager", "Blackboard Bold - \\mathbb{} (amssymb)"), 
QT_TRANSLATE_NOOP("ConfigManager", "Fraktur - \\mathfrak{} (amssymb)"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\overset (amsmath)"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\underset (amsmath)"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\sideset (amsmath)"), 
QT_TRANSLATE_NOOP("ConfigManager", "\\prescript (mathtools)"), 
QT_TRANSLATE_NOOP("ConfigManager", "Negative - \\!"), 
QT_TRANSLATE_NOOP("ConfigManager", "Negative thin space"), 
QT_TRANSLATE_NOOP("ConfigManager", "Thin - \\,"), 
QT_TRANSLATE_NOOP("ConfigManager", "3/18 of a \\quad"), 
QT_TRANSLATE_NOOP("ConfigManager", "Medium - \\:"), 
QT_TRANSLATE_NOOP("ConfigManager", "4/18 of a \\quad"), 
QT_TRANSLATE_NOOP("ConfigManager", "Thick - \\;"), 
QT_TRANSLATE_NOOP("ConfigManager", "5/18 of a \\quad"), 
QT_TRANSLATE_NOOP("ConfigManager", "Interword - \\ "), 
QT_TRANSLATE_NOOP("ConfigManager", "regular whitespace"), 
QT_TRANSLATE_NOOP("ConfigManager", "One quad - \\quad"), 
QT_TRANSLATE_NOOP("ConfigManager", "The \\quad command inserts a horizontal space of 1em (1em being the width of M)."), 
QT_TRANSLATE_NOOP("ConfigManager", "Two quads - \\qquad"), 
QT_TRANSLATE_NOOP("ConfigManager", "Twice the size of a \\quad"), 
QT_TRANSLATE_NOOP("ConfigManager", "ref"), 
QT_TRANSLATE_NOOP("ConfigManager", "eqref"), 
QT_TRANSLATE_NOOP("ConfigManager", "pageref"), 
QT_TRANSLATE_NOOP("QFormatConfig", "background"), 
QT_TRANSLATE_NOOP("QFormatConfig", "line:error"), 
QT_TRANSLATE_NOOP("QFormatConfig", "line:warning"), 
QT_TRANSLATE_NOOP("QFormatConfig", "line:badbox"), 
QT_TRANSLATE_NOOP("QFormatConfig", "line:bookmark"), 
QT_TRANSLATE_NOOP("QFormatConfig", "line:bookmark0"), 
QT_TRANSLATE_NOOP("QFormatConfig", "line:bookmark1"), 
QT_TRANSLATE_NOOP("QFormatConfig", "line:bookmark2"), 
QT_TRANSLATE_NOOP("QFormatConfig", "line:bookmark3"), 
QT_TRANSLATE_NOOP("QFormatConfig", "line:bookmark4"), 
QT_TRANSLATE_NOOP("QFormatConfig", "line:bookmark5"), 
QT_TRANSLATE_NOOP("QFormatConfig", "line:bookmark6"), 
QT_TRANSLATE_NOOP("QFormatConfig", "line:bookmark7"), 
QT_TRANSLATE_NOOP("QFormatConfig", "line:bookmark8"), 
QT_TRANSLATE_NOOP("QFormatConfig", "line:bookmark9"), 
QT_TRANSLATE_NOOP("QFormatConfig", "magicComment"), 
QT_TRANSLATE_NOOP("QFormatConfig", "commentTodo"), 
QT_TRANSLATE_NOOP("QFormatConfig", "comment"), 
QT_TRANSLATE_NOOP("QFormatConfig", "keyword"), 
QT_TRANSLATE_NOOP("QFormatConfig", "extra-keyword"), 
QT_TRANSLATE_NOOP("QFormatConfig", "math-keyword"), 
QT_TRANSLATE_NOOP("QFormatConfig", "link"), 
QT_TRANSLATE_NOOP("QFormatConfig", "align-ampersand"), 
QT_TRANSLATE_NOOP("QFormatConfig", "verbatim"), 
QT_TRANSLATE_NOOP("QFormatConfig", "sweave-block"), 
QT_TRANSLATE_NOOP("QFormatConfig", "sweave-delimiter"), 
QT_TRANSLATE_NOOP("QFormatConfig", "pweave-block"), 
QT_TRANSLATE_NOOP("QFormatConfig", "pweave-delimiter"), 
QT_TRANSLATE_NOOP("QFormatConfig", "picture"), 
QT_TRANSLATE_NOOP("QFormatConfig", "picture-keyword"), 
QT_TRANSLATE_NOOP("QFormatConfig", "braceMatch"), 
QT_TRANSLATE_NOOP("QFormatConfig", "braceMismatch"), 
QT_TRANSLATE_NOOP("QFormatConfig", "search"), 
QT_TRANSLATE_NOOP("QFormatConfig", "numbers"), 
QT_TRANSLATE_NOOP("QFormatConfig", "math-delimiter"), 
QT_TRANSLATE_NOOP("QFormatConfig", "math-text"), 
QT_TRANSLATE_NOOP("QFormatConfig", "text"), 
QT_TRANSLATE_NOOP("QFormatConfig", "escapeseq"), 
QT_TRANSLATE_NOOP("QFormatConfig", "spellingMistake"), 
QT_TRANSLATE_NOOP("QFormatConfig", "wordRepetition"), 
QT_TRANSLATE_NOOP("QFormatConfig", "wordRepetitionLongRange"), 
QT_TRANSLATE_NOOP("QFormatConfig", "badWord"), 
QT_TRANSLATE_NOOP("QFormatConfig", "grammarMistake"), 
QT_TRANSLATE_NOOP("QFormatConfig", "grammarMistakeSpecial1"), 
QT_TRANSLATE_NOOP("QFormatConfig", "grammarMistakeSpecial2"), 
QT_TRANSLATE_NOOP("QFormatConfig", "grammarMistakeSpecial3"), 
QT_TRANSLATE_NOOP("QFormatConfig", "grammarMistakeSpecial4"), 
QT_TRANSLATE_NOOP("QFormatConfig", "latexSyntaxMistake"), 
QT_TRANSLATE_NOOP("QFormatConfig", "temporaryCodeCompletion"), 
QT_TRANSLATE_NOOP("QFormatConfig", "environment"), 
QT_TRANSLATE_NOOP("QFormatConfig", "referencePresent"), 
QT_TRANSLATE_NOOP("QFormatConfig", "referenceMissing"), 
QT_TRANSLATE_NOOP("QFormatConfig", "referenceMultiple"), 
QT_TRANSLATE_NOOP("QFormatConfig", "citationPresent"), 
QT_TRANSLATE_NOOP("QFormatConfig", "citationMissing"), 
QT_TRANSLATE_NOOP("QFormatConfig", "packagePresent"), 
QT_TRANSLATE_NOOP("QFormatConfig", "packageMissing"), 
QT_TRANSLATE_NOOP("QFormatConfig", "structure"), 
QT_TRANSLATE_NOOP("QFormatConfig", "current"), 
QT_TRANSLATE_NOOP("QFormatConfig", "selection"), 
QT_TRANSLATE_NOOP("QFormatConfig", "replacement"), 
QT_TRANSLATE_NOOP("QFormatConfig", "diffDelete"), 
QT_TRANSLATE_NOOP("QFormatConfig", "diffAdd"), 
QT_TRANSLATE_NOOP("QFormatConfig", "diffReplace"), 
QT_TRANSLATE_NOOP("QFormatConfig", "previewSelection"), 
QT_TRANSLATE_NOOP("QFormatConfig", "txs-test"), 
QT_TRANSLATE_NOOP("QFormatConfig", "txs-test-summary"), 
QT_TRANSLATE_NOOP("QFormatConfig", "txs-test-pass"), 
QT_TRANSLATE_NOOP("QFormatConfig", "txs-test-fail"), 
QT_TRANSLATE_NOOP("QFormatConfig", "txs-test-warn"), 
QT_TRANSLATE_NOOP("QFormatConfig", "txs-test-qdebug"), 
QT_TRANSLATE_NOOP("QFormatConfig", "dtx:guard"), 
QT_TRANSLATE_NOOP("QFormatConfig", "dtx:macro"), 
QT_TRANSLATE_NOOP("QFormatConfig", "dtx:verbatim"), 
QT_TRANSLATE_NOOP("QFormatConfig", "dtx:specialchar"), 
QT_TRANSLATE_NOOP("QFormatConfig", "dtx:commands"), 
QT_TRANSLATE_NOOP("QFormatConfig", "lua:keyword"), 
QT_TRANSLATE_NOOP("QFormatConfig", "lua:comment"), 
QT_TRANSLATE_NOOP("QFormatConfig", "asymptote:block"), 
QT_TRANSLATE_NOOP("QFormatConfig", "asymptote:keyword"), 
QT_TRANSLATE_NOOP("QFormatConfig", "asymptote:type"), 
QT_TRANSLATE_NOOP("QFormatConfig", "asymptote:numbers"), 
QT_TRANSLATE_NOOP("QFormatConfig", "asymptote:string"), 
QT_TRANSLATE_NOOP("QFormatConfig", "asymptote:comment"), 
QT_TRANSLATE_NOOP("QFormatConfig", "qtscript:comment"), 
QT_TRANSLATE_NOOP("QFormatConfig", "qtscript:string"), 
QT_TRANSLATE_NOOP("QFormatConfig", "qtscript:number"), 
QT_TRANSLATE_NOOP("QFormatConfig", "qtscript:keyword"), 
QT_TRANSLATE_NOOP("QFormatConfig", "qtscript:txs-variable"), 
QT_TRANSLATE_NOOP("QFormatConfig", "qtscript:txs-function"), 
QT_TRANSLATE_NOOP("QFormatConfig", "braceLevel0"), 
QT_TRANSLATE_NOOP("QFormatConfig", "braceLevel1"), 
QT_TRANSLATE_NOOP("QFormatConfig", "braceLevel2"), 
QT_TRANSLATE_NOOP("QFormatConfig", "braceLevel3"), 
QT_TRANSLATE_NOOP("QFormatConfig", "braceLevel4"), 
QT_TRANSLATE_NOOP("QFormatConfig", "braceLevel5"), 
QT_TRANSLATE_NOOP("QFormatConfig", "braceLevel6"), 
QT_TRANSLATE_NOOP("QFormatConfig", "braceLevel7"), 
QT_TRANSLATE_NOOP("QFormatConfig", "preedit"), 
QT_TRANSLATE_NOOP("QFormatConfig", "normal"),
QT_TRANSLATE_NOOP("Texstudio","Custom"),
QT_TRANSLATE_NOOP("Texstudio","File"),
QT_TRANSLATE_NOOP("Texstudio","Edit"),
QT_TRANSLATE_NOOP("Texstudio","Tools"),
QT_TRANSLATE_NOOP("Texstudio","Math"),
QT_TRANSLATE_NOOP("Texstudio","Format"),
QT_TRANSLATE_NOOP("Texstudio","Table"),
QT_TRANSLATE_NOOP("Texstudio","Diff"),
QT_TRANSLATE_NOOP("Texstudio","Review"),
QT_TRANSLATE_NOOP("Texstudio","Central"),
QT_TRANSLATE_NOOP("Texstudio", "Asymptote", "Format name of language definition "), 
QT_TRANSLATE_NOOP("Texstudio", "BibTeX", "Format name of language definition "), 
QT_TRANSLATE_NOOP("Texstudio", "Binary", "Format name of language definition "), 
QT_TRANSLATE_NOOP("Texstudio", "TeX dtx file", "Format name of language definition "), 
QT_TRANSLATE_NOOP("Texstudio", "Homespring", "Format name of language definition "), 
QT_TRANSLATE_NOOP("Texstudio", "Lua", "Format name of language definition "), 
QT_TRANSLATE_NOOP("Texstudio", "Pweave", "Format name of language definition "), 
QT_TRANSLATE_NOOP("Texstudio", "QtScript", "Format name of language definition "), 
QT_TRANSLATE_NOOP("Texstudio", "Sweave", "Format name of language definition "), 
QT_TRANSLATE_NOOP("Texstudio", "(La)TeX", "Format name of language definition "), 
QT_TRANSLATE_NOOP("Texstudio", "(La)TeX Macro", "Format name of language definition "), 
QT_TRANSLATE_NOOP("Texstudio", "TXS Test Results", "Format name of language definition "), 
QT_TRANSLATE_NOOP("Texstudio", "Plain text", "Format name of language definition "), 
QT_TRANSLATE_NOOP("Texstudio", "XML", "Format name of language definition "), 
""};
#endif

