/****************************************************************************
** Meta object code from reading C++ file 'grammarcheck.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../texstudio-4.9.3/src/grammarcheck.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'grammarcheck.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12GrammarCheckE_t {};
} // unnamed namespace

template <> constexpr inline auto GrammarCheck::qt_create_metaobjectdata<qt_meta_tag_ZN12GrammarCheckE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GrammarCheck",
        "checked",
        "",
        "LatexDocument*",
        "doc",
        "QDocumentLineHandle*",
        "line",
        "lineNr",
        "QList<GrammarError>",
        "errors",
        "languageToolStatusChanged",
        "errorMessage",
        "message",
        "init",
        "LatexParser",
        "lp",
        "GrammarCheckerConfig",
        "config",
        "check",
        "language",
        "QList<LineInfo>",
        "lines",
        "firstLineNr",
        "shutdown",
        "processLoop",
        "process",
        "reqId",
        "backendChecked",
        "ticket",
        "subticket",
        "directCall",
        "updateLTStatus"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'checked'
        QtMocHelpers::SignalData<void(LatexDocument *, QDocumentLineHandle *, int, QList<GrammarError>)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 }, { QMetaType::Int, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Signal 'languageToolStatusChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorMessage'
        QtMocHelpers::SignalData<void(QString)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'init'
        QtMocHelpers::SlotData<void(const LatexParser &, const GrammarCheckerConfig &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { 0x80000000 | 16, 17 },
        }}),
        // Slot 'check'
        QtMocHelpers::SlotData<void(const QString &, LatexDocument *, const QList<LineInfo> &, int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 }, { 0x80000000 | 3, 4 }, { 0x80000000 | 20, 21 }, { QMetaType::Int, 22 },
        }}),
        // Slot 'shutdown'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'processLoop'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'process'
        QtMocHelpers::SlotData<void(int)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'backendChecked'
        QtMocHelpers::SlotData<void(uint, int, const QList<GrammarError> &, bool)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 28 }, { QMetaType::Int, 29 }, { 0x80000000 | 8, 9 }, { QMetaType::Bool, 30 },
        }}),
        // Slot 'backendChecked'
        QtMocHelpers::SlotData<void(uint, int, const QList<GrammarError> &)>(27, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::UInt, 28 }, { QMetaType::Int, 29 }, { 0x80000000 | 8, 9 },
        }}),
        // Slot 'updateLTStatus'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GrammarCheck, qt_meta_tag_ZN12GrammarCheckE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject GrammarCheck::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12GrammarCheckE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12GrammarCheckE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12GrammarCheckE_t>.metaTypes,
    nullptr
} };

void GrammarCheck::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GrammarCheck *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->checked((*reinterpret_cast<std::add_pointer_t<LatexDocument*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDocumentLineHandle*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QList<GrammarError>>>(_a[4]))); break;
        case 1: _t->languageToolStatusChanged(); break;
        case 2: _t->errorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->init((*reinterpret_cast<std::add_pointer_t<LatexParser>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<GrammarCheckerConfig>>(_a[2]))); break;
        case 4: _t->check((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<LatexDocument*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<LineInfo>>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 5: _t->shutdown(); break;
        case 6: _t->processLoop(); break;
        case 7: _t->process((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->backendChecked((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<GrammarError>>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 9: _t->backendChecked((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<GrammarError>>>(_a[3]))); break;
        case 10: _t->updateLTStatus(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<GrammarError> >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< GrammarCheckerConfig >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< LatexParser >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<LineInfo> >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<GrammarError> >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<GrammarError> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GrammarCheck::*)(LatexDocument * , QDocumentLineHandle * , int , QList<GrammarError> )>(_a, &GrammarCheck::checked, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GrammarCheck::*)()>(_a, &GrammarCheck::languageToolStatusChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (GrammarCheck::*)(QString )>(_a, &GrammarCheck::errorMessage, 2))
            return;
    }
}

const QMetaObject *GrammarCheck::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GrammarCheck::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12GrammarCheckE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int GrammarCheck::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void GrammarCheck::checked(LatexDocument * _t1, QDocumentLineHandle * _t2, int _t3, QList<GrammarError> _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 1
void GrammarCheck::languageToolStatusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void GrammarCheck::errorMessage(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN19GrammarCheckBackendE_t {};
} // unnamed namespace

template <> constexpr inline auto GrammarCheckBackend::qt_create_metaobjectdata<qt_meta_tag_ZN19GrammarCheckBackendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GrammarCheckBackend",
        "checked",
        "",
        "ticket",
        "subticket",
        "QList<GrammarError>",
        "errors",
        "languageToolStatusChanged",
        "errorMessage",
        "message"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'checked'
        QtMocHelpers::SignalData<void(uint, int, const QList<GrammarError> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::Int, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'languageToolStatusChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorMessage'
        QtMocHelpers::SignalData<void(QString)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GrammarCheckBackend, qt_meta_tag_ZN19GrammarCheckBackendE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject GrammarCheckBackend::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19GrammarCheckBackendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19GrammarCheckBackendE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19GrammarCheckBackendE_t>.metaTypes,
    nullptr
} };

void GrammarCheckBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GrammarCheckBackend *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->checked((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<GrammarError>>>(_a[3]))); break;
        case 1: _t->languageToolStatusChanged(); break;
        case 2: _t->errorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<GrammarError> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GrammarCheckBackend::*)(uint , int , const QList<GrammarError> & )>(_a, &GrammarCheckBackend::checked, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GrammarCheckBackend::*)()>(_a, &GrammarCheckBackend::languageToolStatusChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (GrammarCheckBackend::*)(QString )>(_a, &GrammarCheckBackend::errorMessage, 2))
            return;
    }
}

const QMetaObject *GrammarCheckBackend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GrammarCheckBackend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19GrammarCheckBackendE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int GrammarCheckBackend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void GrammarCheckBackend::checked(uint _t1, int _t2, const QList<GrammarError> & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void GrammarCheckBackend::languageToolStatusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void GrammarCheckBackend::errorMessage(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN28GrammarCheckLanguageToolJSONE_t {};
} // unnamed namespace

template <> constexpr inline auto GrammarCheckLanguageToolJSON::qt_create_metaobjectdata<qt_meta_tag_ZN28GrammarCheckLanguageToolJSONE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GrammarCheckLanguageToolJSON",
        "finished",
        "",
        "QNetworkReply*",
        "reply"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'finished'
        QtMocHelpers::SlotData<void(QNetworkReply *)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GrammarCheckLanguageToolJSON, qt_meta_tag_ZN28GrammarCheckLanguageToolJSONE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject GrammarCheckLanguageToolJSON::staticMetaObject = { {
    QMetaObject::SuperData::link<GrammarCheckBackend::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28GrammarCheckLanguageToolJSONE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28GrammarCheckLanguageToolJSONE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN28GrammarCheckLanguageToolJSONE_t>.metaTypes,
    nullptr
} };

void GrammarCheckLanguageToolJSON::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GrammarCheckLanguageToolJSON *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->finished((*reinterpret_cast<std::add_pointer_t<QNetworkReply*>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *GrammarCheckLanguageToolJSON::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GrammarCheckLanguageToolJSON::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28GrammarCheckLanguageToolJSONE_t>.strings))
        return static_cast<void*>(this);
    return GrammarCheckBackend::qt_metacast(_clname);
}

int GrammarCheckLanguageToolJSON::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = GrammarCheckBackend::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
