/****************************************************************************
** Meta object code from reading C++ file 'latexeditorview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../texstudio-4.9.3/src/latexeditorview.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'latexeditorview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15LatexEditorViewE_t {};
} // unnamed namespace

template <> constexpr inline auto LatexEditorView::qt_create_metaobjectdata<qt_meta_tag_ZN15LatexEditorViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LatexEditorView",
        "lineHandleDeleted",
        "",
        "QDocumentLineHandle*",
        "l",
        "showMarkTooltipForLogMessage",
        "QList<int>",
        "logMessages",
        "needCitation",
        "id",
        "showPreview",
        "text",
        "QDocumentCursor",
        "c",
        "showImgPreview",
        "fileName",
        "showFullPreview",
        "openFile",
        "name",
        "baseName",
        "defaultExtension",
        "openCompleter",
        "thesaurus",
        "line",
        "col",
        "changeDiff",
        "QPoint",
        "pt",
        "spellerChanged",
        "gotoDefinition",
        "findLabelUsages",
        "LatexDocument*",
        "contextDoc",
        "labelText",
        "findSpecialUsages",
        "doc",
        "type",
        "syncPDFRequested",
        "bookmarkRemoved",
        "dlh",
        "bookmarkAdded",
        "nr",
        "saveCurrentCursorToHistoryRequested",
        "execMacro",
        "Macro",
        "macro",
        "MacroExecContext",
        "context",
        "mouseBackPressed",
        "mouseForwardPressed",
        "cursorChangeByMouse",
        "focusReceived",
        "linesChanged",
        "language",
        "QList<LineInfo>",
        "lines",
        "firstLineNr",
        "searchBibtexSection",
        "file",
        "bibId",
        "openInternalDocViewer",
        "package",
        "command",
        "showExtendedSearch",
        "requestCitation",
        "openExternalFile",
        "openPackageDocumentation",
        "emitChangeDiff",
        "emitGotoDefinitionFromAction",
        "emitFindLabelUsagesFromAction",
        "emitFindSpecialUsagesFromAction",
        "emitSyncPDFFromAction",
        "lineMarkClicked",
        "lineMarkToolTip",
        "mark",
        "triggeredThesaurus",
        "reloadSpeller",
        "copyImageFromAction",
        "saveImageFromAction",
        "changeSpellingDict",
        "cleanBib",
        "jumpChangePositionBackward",
        "jumpChangePositionForward",
        "jumpToBookmark",
        "bookmarkNumber",
        "toggleBookmark",
        "QDocumentLine",
        "foldEverything",
        "unFold",
        "foldLevel",
        "level",
        "foldBlockAt",
        "zoomIn",
        "zoomOut",
        "resetZoom",
        "mayNeedToOpenCompleter",
        "fromSingleChar",
        "documentContentChanged",
        "linenr",
        "count",
        "reCheckSyntax",
        "checkGrammar",
        "lineDeleted",
        "hint",
        "textReplaceFromAction",
        "spellCheckingAddToDict",
        "spellCheckingIgnoreAll",
        "populateSpellingMenu",
        "addReplaceActions",
        "QMenu*",
        "menu",
        "replacements",
        "italic",
        "addSpellingActions",
        "word",
        "dedicatedMenu",
        "spellRemoveMarkers",
        "newIgnoredWord",
        "mouseHovered",
        "pos",
        "closeElement",
        "insertHardLineBreaks",
        "newLength",
        "smartScopeSelection",
        "joinLines",
        "temporaryHighlight",
        "cur",
        "removeTemporaryHighlight",
        "displayLineGrammarErrorsInternal",
        "lineNr",
        "QList<GrammarError>",
        "errors",
        "lineGrammarChecked",
        "updateGrammarOverlays",
        "bibtexSectionFound",
        "content",
        "lineMarkContextMenuRequested",
        "lineNumber",
        "globalPos",
        "foldContextMenuRequested",
        "displayName",
        "complete",
        "flags",
        "getSpeller",
        "closeCompleter",
        "removeBookmark",
        "addBookmark",
        "hasBookmark",
        "editor",
        "QEditor*",
        "document"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'lineHandleDeleted'
        QtMocHelpers::SignalData<void(QDocumentLineHandle *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'showMarkTooltipForLogMessage'
        QtMocHelpers::SignalData<void(QList<int>)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'needCitation'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'showPreview'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'showPreview'
        QtMocHelpers::SignalData<void(const QDocumentCursor &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'showImgPreview'
        QtMocHelpers::SignalData<void(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Signal 'showFullPreview'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openFile'
        QtMocHelpers::SignalData<void(const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
        // Signal 'openFile'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 }, { QMetaType::QString, 20 },
        }}),
        // Signal 'openCompleter'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'thesaurus'
        QtMocHelpers::SignalData<void(int, int)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 }, { QMetaType::Int, 24 },
        }}),
        // Signal 'changeDiff'
        QtMocHelpers::SignalData<void(QPoint)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Signal 'spellerChanged'
        QtMocHelpers::SignalData<void(const QString &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
        // Signal 'gotoDefinition'
        QtMocHelpers::SignalData<void(QDocumentCursor)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'findLabelUsages'
        QtMocHelpers::SignalData<void(LatexDocument *, const QString &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 32 }, { QMetaType::QString, 33 },
        }}),
        // Signal 'findSpecialUsages'
        QtMocHelpers::SignalData<void(LatexDocument *, const QString &, int)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 35 }, { QMetaType::QString, 33 }, { QMetaType::Int, 36 },
        }}),
        // Signal 'syncPDFRequested'
        QtMocHelpers::SignalData<void(QDocumentCursor)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'bookmarkRemoved'
        QtMocHelpers::SignalData<void(QDocumentLineHandle *)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 39 },
        }}),
        // Signal 'bookmarkAdded'
        QtMocHelpers::SignalData<void(QDocumentLineHandle *, int)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 39 }, { QMetaType::Int, 41 },
        }}),
        // Signal 'saveCurrentCursorToHistoryRequested'
        QtMocHelpers::SignalData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'execMacro'
        QtMocHelpers::SignalData<void(const Macro &, const MacroExecContext &)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 44, 45 }, { 0x80000000 | 46, 47 },
        }}),
        // Signal 'mouseBackPressed'
        QtMocHelpers::SignalData<void()>(48, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mouseForwardPressed'
        QtMocHelpers::SignalData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cursorChangeByMouse'
        QtMocHelpers::SignalData<void()>(50, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusReceived'
        QtMocHelpers::SignalData<void()>(51, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'linesChanged'
        QtMocHelpers::SignalData<void(QString, LatexDocument *, const QList<LineInfo> &, int)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 53 }, { 0x80000000 | 31, 35 }, { 0x80000000 | 54, 55 }, { QMetaType::Int, 56 },
        }}),
        // Signal 'searchBibtexSection'
        QtMocHelpers::SignalData<void(QString, QString)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 58 }, { QMetaType::QString, 59 },
        }}),
        // Signal 'openInternalDocViewer'
        QtMocHelpers::SignalData<void(QString, QString)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 61 }, { QMetaType::QString, 62 },
        }}),
        // Signal 'openInternalDocViewer'
        QtMocHelpers::SignalData<void(QString)>(60, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 61 },
        }}),
        // Signal 'showExtendedSearch'
        QtMocHelpers::SignalData<void()>(63, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'requestCitation'
        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openExternalFile'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openPackageDocumentation'
        QtMocHelpers::SlotData<void(QString)>(66, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 61 },
        }}),
        // Slot 'openPackageDocumentation'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'emitChangeDiff'
        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'emitGotoDefinitionFromAction'
        QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'emitFindLabelUsagesFromAction'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'emitFindSpecialUsagesFromAction'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'emitSyncPDFFromAction'
        QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'lineMarkClicked'
        QtMocHelpers::SlotData<void(int)>(72, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'lineMarkToolTip'
        QtMocHelpers::SlotData<void(int, int)>(73, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 23 }, { QMetaType::Int, 74 },
        }}),
        // Slot 'triggeredThesaurus'
        QtMocHelpers::SlotData<void()>(75, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'reloadSpeller'
        QtMocHelpers::SlotData<void()>(76, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'copyImageFromAction'
        QtMocHelpers::SlotData<void()>(77, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveImageFromAction'
        QtMocHelpers::SlotData<void()>(78, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'changeSpellingDict'
        QtMocHelpers::SlotData<void(const QString &)>(79, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
        // Slot 'cleanBib'
        QtMocHelpers::SlotData<void()>(80, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'jumpChangePositionBackward'
        QtMocHelpers::SlotData<void()>(81, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'jumpChangePositionForward'
        QtMocHelpers::SlotData<void()>(82, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'jumpToBookmark'
        QtMocHelpers::SlotData<void(int)>(83, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 84 },
        }}),
        // Slot 'toggleBookmark'
        QtMocHelpers::SlotData<bool(int, QDocumentLine)>(85, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 84 }, { 0x80000000 | 86, 23 },
        }}),
        // Slot 'toggleBookmark'
        QtMocHelpers::SlotData<bool(int)>(85, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Int, 84 },
        }}),
        // Slot 'foldEverything'
        QtMocHelpers::SlotData<void(bool)>(87, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 88 },
        }}),
        // Slot 'foldLevel'
        QtMocHelpers::SlotData<void(bool, int)>(89, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 88 }, { QMetaType::Int, 90 },
        }}),
        // Slot 'foldBlockAt'
        QtMocHelpers::SlotData<void(bool, int)>(91, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 88 }, { QMetaType::Int, 23 },
        }}),
        // Slot 'zoomIn'
        QtMocHelpers::SlotData<void()>(92, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomOut'
        QtMocHelpers::SlotData<void()>(93, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resetZoom'
        QtMocHelpers::SlotData<void()>(94, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'mayNeedToOpenCompleter'
        QtMocHelpers::SlotData<void(bool)>(95, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 96 },
        }}),
        // Slot 'mayNeedToOpenCompleter'
        QtMocHelpers::SlotData<void()>(95, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'documentContentChanged'
        QtMocHelpers::SlotData<void(int, int)>(97, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 98 }, { QMetaType::Int, 99 },
        }}),
        // Slot 'reCheckSyntax'
        QtMocHelpers::SlotData<void(int, int)>(100, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 98 }, { QMetaType::Int, 99 },
        }}),
        // Slot 'reCheckSyntax'
        QtMocHelpers::SlotData<void(int)>(100, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 98 },
        }}),
        // Slot 'checkGrammar'
        QtMocHelpers::SlotData<void(int, int)>(101, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 98 }, { QMetaType::Int, 99 },
        }}),
        // Slot 'lineDeleted'
        QtMocHelpers::SlotData<void(QDocumentLineHandle *, int)>(102, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Int, 103 },
        }}),
        // Slot 'lineDeleted'
        QtMocHelpers::SlotData<void(QDocumentLineHandle *)>(102, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'textReplaceFromAction'
        QtMocHelpers::SlotData<void()>(104, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'spellCheckingAddToDict'
        QtMocHelpers::SlotData<void()>(105, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'spellCheckingIgnoreAll'
        QtMocHelpers::SlotData<void()>(106, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'populateSpellingMenu'
        QtMocHelpers::SlotData<void()>(107, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addReplaceActions'
        QtMocHelpers::SlotData<void(QMenu *, const QStringList &, bool)>(108, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 109, 110 }, { QMetaType::QStringList, 111 }, { QMetaType::Bool, 112 },
        }}),
        // Slot 'addSpellingActions'
        QtMocHelpers::SlotData<void(QMenu *, QString, bool)>(113, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 109, 110 }, { QMetaType::QString, 114 }, { QMetaType::Bool, 115 },
        }}),
        // Slot 'spellRemoveMarkers'
        QtMocHelpers::SlotData<void(const QString &)>(116, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 117 },
        }}),
        // Slot 'mouseHovered'
        QtMocHelpers::SlotData<void(QPoint)>(118, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 119 },
        }}),
        // Slot 'closeElement'
        QtMocHelpers::SlotData<bool()>(120, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'insertHardLineBreaks'
        QtMocHelpers::SlotData<void(int, bool, bool)>(121, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 122 }, { QMetaType::Bool, 123 }, { QMetaType::Bool, 124 },
        }}),
        // Slot 'temporaryHighlight'
        QtMocHelpers::SlotData<void(QDocumentCursor)>(125, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 126 },
        }}),
        // Slot 'removeTemporaryHighlight'
        QtMocHelpers::SlotData<void()>(127, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'displayLineGrammarErrorsInternal'
        QtMocHelpers::SlotData<void(int, const QList<GrammarError> &)>(128, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 129 }, { 0x80000000 | 130, 131 },
        }}),
        // Slot 'lineGrammarChecked'
        QtMocHelpers::SlotData<void(LatexDocument *, QDocumentLineHandle *, int, const QList<GrammarError> &)>(132, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 35 }, { 0x80000000 | 3, 23 }, { QMetaType::Int, 129 }, { 0x80000000 | 130, 131 },
        }}),
        // Slot 'updateGrammarOverlays'
        QtMocHelpers::SlotData<void()>(133, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'bibtexSectionFound'
        QtMocHelpers::SlotData<void(QString)>(134, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 135 },
        }}),
        // Slot 'lineMarkContextMenuRequested'
        QtMocHelpers::SlotData<void(int, QPoint)>(136, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 137 }, { 0x80000000 | 26, 138 },
        }}),
        // Slot 'foldContextMenuRequested'
        QtMocHelpers::SlotData<void(int, QPoint)>(139, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 137 }, { 0x80000000 | 26, 138 },
        }}),
        // Method 'displayName'
        QtMocHelpers::MethodData<QString() const>(140, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'complete'
        QtMocHelpers::MethodData<void(int)>(141, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 142 },
        }}),
        // Method 'getSpeller'
        QtMocHelpers::MethodData<QString()>(143, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'closeCompleter'
        QtMocHelpers::MethodData<void()>(144, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'removeBookmark'
        QtMocHelpers::MethodData<void(int, int)>(145, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 129 }, { QMetaType::Int, 84 },
        }}),
        // Method 'addBookmark'
        QtMocHelpers::MethodData<void(int, int)>(146, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 129 }, { QMetaType::Int, 84 },
        }}),
        // Method 'hasBookmark'
        QtMocHelpers::MethodData<bool(int, int)>(147, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 129 }, { QMetaType::Int, 84 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'editor'
        QtMocHelpers::PropertyData<QEditor*>(148, 0x80000000 | 149, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'document'
        QtMocHelpers::PropertyData<LatexDocument*>(150, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LatexEditorView, qt_meta_tag_ZN15LatexEditorViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LatexEditorView::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15LatexEditorViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15LatexEditorViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15LatexEditorViewE_t>.metaTypes,
    nullptr
} };

void LatexEditorView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LatexEditorView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->lineHandleDeleted((*reinterpret_cast<std::add_pointer_t<QDocumentLineHandle*>>(_a[1]))); break;
        case 1: _t->showMarkTooltipForLogMessage((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1]))); break;
        case 2: _t->needCitation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->showPreview((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->showPreview((*reinterpret_cast<std::add_pointer_t<QDocumentCursor>>(_a[1]))); break;
        case 5: _t->showImgPreview((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->showFullPreview(); break;
        case 7: _t->openFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->openFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 9: _t->openCompleter(); break;
        case 10: _t->thesaurus((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 11: _t->changeDiff((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 12: _t->spellerChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->gotoDefinition((*reinterpret_cast<std::add_pointer_t<QDocumentCursor>>(_a[1]))); break;
        case 14: _t->findLabelUsages((*reinterpret_cast<std::add_pointer_t<LatexDocument*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 15: _t->findSpecialUsages((*reinterpret_cast<std::add_pointer_t<LatexDocument*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 16: _t->syncPDFRequested((*reinterpret_cast<std::add_pointer_t<QDocumentCursor>>(_a[1]))); break;
        case 17: _t->bookmarkRemoved((*reinterpret_cast<std::add_pointer_t<QDocumentLineHandle*>>(_a[1]))); break;
        case 18: _t->bookmarkAdded((*reinterpret_cast<std::add_pointer_t<QDocumentLineHandle*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 19: _t->saveCurrentCursorToHistoryRequested(); break;
        case 20: _t->execMacro((*reinterpret_cast<std::add_pointer_t<Macro>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<MacroExecContext>>(_a[2]))); break;
        case 21: _t->mouseBackPressed(); break;
        case 22: _t->mouseForwardPressed(); break;
        case 23: _t->cursorChangeByMouse(); break;
        case 24: _t->focusReceived(); break;
        case 25: _t->linesChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<LatexDocument*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<LineInfo>>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 26: _t->searchBibtexSection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 27: _t->openInternalDocViewer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 28: _t->openInternalDocViewer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 29: _t->showExtendedSearch(); break;
        case 30: _t->requestCitation(); break;
        case 31: _t->openExternalFile(); break;
        case 32: _t->openPackageDocumentation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 33: _t->openPackageDocumentation(); break;
        case 34: _t->emitChangeDiff(); break;
        case 35: _t->emitGotoDefinitionFromAction(); break;
        case 36: _t->emitFindLabelUsagesFromAction(); break;
        case 37: _t->emitFindSpecialUsagesFromAction(); break;
        case 38: _t->emitSyncPDFFromAction(); break;
        case 39: _t->lineMarkClicked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 40: _t->lineMarkToolTip((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 41: _t->triggeredThesaurus(); break;
        case 42: _t->reloadSpeller(); break;
        case 43: _t->copyImageFromAction(); break;
        case 44: _t->saveImageFromAction(); break;
        case 45: _t->changeSpellingDict((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 46: _t->cleanBib(); break;
        case 47: _t->jumpChangePositionBackward(); break;
        case 48: _t->jumpChangePositionForward(); break;
        case 49: _t->jumpToBookmark((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 50: { bool _r = _t->toggleBookmark((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDocumentLine>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 51: { bool _r = _t->toggleBookmark((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 52: _t->foldEverything((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 53: _t->foldLevel((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 54: _t->foldBlockAt((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 55: _t->zoomIn(); break;
        case 56: _t->zoomOut(); break;
        case 57: _t->resetZoom(); break;
        case 58: _t->mayNeedToOpenCompleter((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 59: _t->mayNeedToOpenCompleter(); break;
        case 60: _t->documentContentChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 61: _t->reCheckSyntax((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 62: _t->reCheckSyntax((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 63: _t->checkGrammar((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 64: _t->lineDeleted((*reinterpret_cast<std::add_pointer_t<QDocumentLineHandle*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 65: _t->lineDeleted((*reinterpret_cast<std::add_pointer_t<QDocumentLineHandle*>>(_a[1]))); break;
        case 66: _t->textReplaceFromAction(); break;
        case 67: _t->spellCheckingAddToDict(); break;
        case 68: _t->spellCheckingIgnoreAll(); break;
        case 69: _t->populateSpellingMenu(); break;
        case 70: _t->addReplaceActions((*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 71: _t->addSpellingActions((*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 72: _t->spellRemoveMarkers((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 73: _t->mouseHovered((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 74: { bool _r = _t->closeElement();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 75: _t->insertHardLineBreaks((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 76: _t->temporaryHighlight((*reinterpret_cast<std::add_pointer_t<QDocumentCursor>>(_a[1]))); break;
        case 77: _t->removeTemporaryHighlight(); break;
        case 78: _t->displayLineGrammarErrorsInternal((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<GrammarError>>>(_a[2]))); break;
        case 79: _t->lineGrammarChecked((*reinterpret_cast<std::add_pointer_t<LatexDocument*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDocumentLineHandle*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QList<GrammarError>>>(_a[4]))); break;
        case 80: _t->updateGrammarOverlays(); break;
        case 81: _t->bibtexSectionFound((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 82: _t->lineMarkContextMenuRequested((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 83: _t->foldContextMenuRequested((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 84: { QString _r = _t->displayName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 85: _t->complete((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 86: { QString _r = _t->getSpeller();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 87: _t->closeCompleter(); break;
        case 88: _t->removeBookmark((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 89: _t->addBookmark((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 90: { bool _r = _t->hasBookmark((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDocumentLineHandle* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDocumentCursor >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDocumentCursor >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< LatexDocument* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< LatexDocument* >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDocumentCursor >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDocumentLineHandle* >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDocumentLineHandle* >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< LatexDocument* >(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<LineInfo> >(); break;
            }
            break;
        case 64:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDocumentLineHandle* >(); break;
            }
            break;
        case 65:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDocumentLineHandle* >(); break;
            }
            break;
        case 70:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QMenu* >(); break;
            }
            break;
        case 71:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QMenu* >(); break;
            }
            break;
        case 76:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDocumentCursor >(); break;
            }
            break;
        case 78:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<GrammarError> >(); break;
            }
            break;
        case 79:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< LatexDocument* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDocumentLineHandle* >(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<GrammarError> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LatexEditorView::*)(QDocumentLineHandle * )>(_a, &LatexEditorView::lineHandleDeleted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LatexEditorView::*)(QList<int> )>(_a, &LatexEditorView::showMarkTooltipForLogMessage, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (LatexEditorView::*)(const QString & )>(_a, &LatexEditorView::needCitation, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (LatexEditorView::*)(const QString & )>(_a, &LatexEditorView::showPreview, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (LatexEditorView::*)(const QDocumentCursor & )>(_a, &LatexEditorView::showPreview, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (LatexEditorView::*)(const QString & )>(_a, &LatexEditorView::showImgPreview, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (LatexEditorView::*)()>(_a, &LatexEditorView::showFullPreview, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (LatexEditorView::*)(const QString & )>(_a, &LatexEditorView::openFile, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (LatexEditorView::*)(const QString & , const QString & )>(_a, &LatexEditorView::openFile, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (LatexEditorView::*)()>(_a, &LatexEditorView::openCompleter, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (LatexEditorView::*)(int , int )>(_a, &LatexEditorView::thesaurus, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (LatexEditorView::*)(QPoint )>(_a, &LatexEditorView::changeDiff, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (LatexEditorView::*)(const QString & )>(_a, &LatexEditorView::spellerChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (LatexEditorView::*)(QDocumentCursor )>(_a, &LatexEditorView::gotoDefinition, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (LatexEditorView::*)(LatexDocument * , const QString & )>(_a, &LatexEditorView::findLabelUsages, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (LatexEditorView::*)(LatexDocument * , const QString & , int )>(_a, &LatexEditorView::findSpecialUsages, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (LatexEditorView::*)(QDocumentCursor )>(_a, &LatexEditorView::syncPDFRequested, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (LatexEditorView::*)(QDocumentLineHandle * )>(_a, &LatexEditorView::bookmarkRemoved, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (LatexEditorView::*)(QDocumentLineHandle * , int )>(_a, &LatexEditorView::bookmarkAdded, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (LatexEditorView::*)()>(_a, &LatexEditorView::saveCurrentCursorToHistoryRequested, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (LatexEditorView::*)(const Macro & , const MacroExecContext & )>(_a, &LatexEditorView::execMacro, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (LatexEditorView::*)()>(_a, &LatexEditorView::mouseBackPressed, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (LatexEditorView::*)()>(_a, &LatexEditorView::mouseForwardPressed, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (LatexEditorView::*)()>(_a, &LatexEditorView::cursorChangeByMouse, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (LatexEditorView::*)()>(_a, &LatexEditorView::focusReceived, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (LatexEditorView::*)(QString , LatexDocument * , const QList<LineInfo> & , int )>(_a, &LatexEditorView::linesChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (LatexEditorView::*)(QString , QString )>(_a, &LatexEditorView::searchBibtexSection, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (LatexEditorView::*)(QString , QString )>(_a, &LatexEditorView::openInternalDocViewer, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (LatexEditorView::*)()>(_a, &LatexEditorView::showExtendedSearch, 29))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< LatexDocument* >(); break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QEditor* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QEditor**>(_v) = _t->getEditor(); break;
        case 1: *reinterpret_cast<LatexDocument**>(_v) = _t->getDocument(); break;
        default: break;
        }
    }
}

const QMetaObject *LatexEditorView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LatexEditorView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15LatexEditorViewE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int LatexEditorView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 91)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 91;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 91)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 91;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void LatexEditorView::lineHandleDeleted(QDocumentLineHandle * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void LatexEditorView::showMarkTooltipForLogMessage(QList<int> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void LatexEditorView::needCitation(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void LatexEditorView::showPreview(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void LatexEditorView::showPreview(const QDocumentCursor & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void LatexEditorView::showImgPreview(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void LatexEditorView::showFullPreview()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void LatexEditorView::openFile(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void LatexEditorView::openFile(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void LatexEditorView::openCompleter()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void LatexEditorView::thesaurus(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}

// SIGNAL 11
void LatexEditorView::changeDiff(QPoint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void LatexEditorView::spellerChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void LatexEditorView::gotoDefinition(QDocumentCursor _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void LatexEditorView::findLabelUsages(LatexDocument * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2);
}

// SIGNAL 15
void LatexEditorView::findSpecialUsages(LatexDocument * _t1, const QString & _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1, _t2, _t3);
}

// SIGNAL 16
void LatexEditorView::syncPDFRequested(QDocumentCursor _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void LatexEditorView::bookmarkRemoved(QDocumentLineHandle * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void LatexEditorView::bookmarkAdded(QDocumentLineHandle * _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1, _t2);
}

// SIGNAL 19
void LatexEditorView::saveCurrentCursorToHistoryRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void LatexEditorView::execMacro(const Macro & _t1, const MacroExecContext & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1, _t2);
}

// SIGNAL 21
void LatexEditorView::mouseBackPressed()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void LatexEditorView::mouseForwardPressed()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void LatexEditorView::cursorChangeByMouse()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void LatexEditorView::focusReceived()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void LatexEditorView::linesChanged(QString _t1, LatexDocument * _t2, const QList<LineInfo> & _t3, int _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 26
void LatexEditorView::searchBibtexSection(QString _t1, QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1, _t2);
}

// SIGNAL 27
void LatexEditorView::openInternalDocViewer(QString _t1, QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 27, nullptr, _t1, _t2);
}

// SIGNAL 29
void LatexEditorView::showExtendedSearch()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}
QT_WARNING_POP
